
/******************************************************************************
  * @file    PT32x033x.h
  * @author  ӦÿŶ
  * @version V1.4.0
  * @date    2023/10/27
  * @brief   
  *          
  ******************************************************************************
  * @attention
  *
  *
  *****************************************************************************/

    
#ifndef PT32x033x_H
#define PT32x033x_H

#ifdef __cplusplus
 extern "C" {
#endif

#if defined (__CC_ARM)
#pragma anon_unions
#endif	

#define __CM0_REV			0 	/*!< Core Revision r0p0	*/
#define __MPU_PRESENT		0 	/*!< 033 do not provide MPU	*/
#define __NVIC_PRIO_BITS	2 	/*!< 033 uses 2 Bits for the Priority Levels  */
#define __Vendor_SysTickConfig	0 /*!< Set to 1 if different SysTick Config is used  */
#define _PT32x033x				/*!< MCU Type*/

/**
 * @brief 033 Interrupt Number Definition
 */	
typedef enum IRQn
{
	/******  Cortex-M0 Processor Exceptions Numbers ***************************************************/
	NMI_IRQn     = -14,	/*!< 2 Non Maskable Interrupt	*/
	HardFault_IRQn	= -13,	/*!< 3 Cortex-M0 Hard Fault Interrupt	*/
	SVCall_IRQn		= -5,	/*!< 11 Cortex-M0 SV Call Interrupt	*/
	PendSV_IRQn	= -2,	/*!< 14 Cortex-M0 Pend SV Interrupt	*/
	SysTick_IRQn	= -1,	/*!< 15 Cortex-M0 System Tick Interrupt	*/

	/****** MCU Specific Interrupt Numbers *******************************************************/
	SWDG_IRQn     	=  0 ,      /* WDG        Interrupt  */
	PLLFAIL_IRQn 	=  1 ,      /* PLLFAIL    Interrupt 	*/
	IFMC_IRQn    	=  3 ,      /* IFMC       Interrupt 	*/
	EXTIA_IRQn        	=  5 ,      /* PA          Interrupt 	*/
	EXTIB_IRQn         	=  6 ,      /* PB          Interrupt 	*/
	EXTIC_IRQn        	=  7,	/* PC          Interrupt 	*/
	EXTID_IRQn         	=  8,	/* PD          Interrupt 	*/
	CMP0_IRQn	=  9 ,      /* Comparator0 Interrupt 	*/
	CMP1_IRQn	=  10,      /* Comparator1 Interrupt 	*/
	DAC_IRQn                	=  11,      /* DAC         Interrupt 	*/
	ADC_IRQn                	=  12,      /* ADC         Interrupt 	*/
	TIM1_IRQn             =  13,      /* TIMER1      Interrupt 	*/ 
	TIM0_IRQn             =  14,      /* TIMER0      Interrupt 	*/
	TIM4_IRQn             =  15,      /* TIMER4      Interrupt 	*/
	TIM3_IRQn             =  16,      /* TIMER3      Interrupt 	*/
	TIM2_IRQn             =  17,      /* TIMER2      Interrupt 	*/
	PVD_IRQn                	=  20,      /* PVD         Interrupt 	*/
	I2C_IRQn               	=  23,      /* I2C        Interrupt 	*/
	SPI0_IRQn               	=  25,      /* SPI0        Interrupt 	*/
	SPI1_IRQn               	=  26,      /* SPI1        Interrupt 	*/
	UART0_IRQn              	=  27,      /* UART0     Interrupt 	*/
	RTC_IRQn                	=  29,      /* RTC         Interrupt 	*/
} IRQn_Type;



#include "core_cm0.h"
#include "PT32x033x_Type.h"
#include "system_PT32x033x.h"
#include <stdint.h>


/** @addtogroup Exported_types
  * @{
  */  
typedef enum {RESET = 0, SET = !RESET} FlagStatus, ITStatus, RemapStatus, ProtectStatus;

typedef enum {DISABLE = 0, ENABLE = !DISABLE} FunctionalState;
#define IS_FUNCTIONAL_STATE(STATE) (((STATE) == DISABLE) || ((STATE) == ENABLE))

typedef enum {FALSE = 0, TRUE = !FALSE} bool;
/**
  * @}
  */

/** 
  * @brief ID
**/
typedef struct
{
	__I  u32  UDID;     /* Offset: 0x000 Customer ID information Register (R) */
	u32 RESERVED0[3]; 	
	__I  u32  UID1;   	/* Offset: 0x010 UID information Register         (R) */ 
	__I  u32  UID2;   	/* Offset: 0x014 UID information Register 				(R) */
	__I  u32  UID3;   	/* Offset: 0x018 UID information Register 				(R) */ 
	__I  u32  CID;      /* Offset: 0x01C CID information Register 				(R) */
} ID_TypeDef;

/** 
  * @brief General Purpose IO  
  */
typedef struct
{
	__IO u32  DR;        		/*!< Offset: 0x000 DATA Register (R/W) */
	u32  RESERVED1;         	/*!< Offset: 0x004 Data Output Latch Register (R/W) */
	__IO u32  OES;	/*!< Offset: 0x008 Output Enable Set Register  (R/W) */
	__IO u32  OEC; 	/*!< Offset: 0x00C Output Enable Clear Register  (R/W) */
	u32  RESERVED2[12];
	__IO u32  PUS;		/*!< Offset: 0x040 Pull Up Set Register  (R/W) */
	__IO u32  PUC;		/*!< Offset: 0x044 Pull Up Clear Register  (R/W) */
	__IO u32  PDS;	/*!< Offset: 0x048 Pull Down Set Register  (R/W) */
	__IO u32  PDC;	/*!< Offset: 0x04C Pull Down Clear Register  (R/W) */
	__IO u32  ODS;		/*!< Offset: 0x050 Open Drain Set Register  (R/W) */
	__IO u32  ODC;		/*!< Offset: 0x054 Open Drain Clear Register  (R/W) */
		u32  RESERVED3[234];
	__O u32  MASKL[256];	/*!< Offset: 0x400 - 0x7FC Lower byte Masked Access Register (R/W) */
	__O u32  MASKH[256];	/*!< Offset: 0x800 - 0xBFC Upper byte Masked Access Register (R/W) */} GPIO_TypeDef;

/**
 * @brief AFIO
**/
typedef struct
{   
  __IO u32  AFS0;	  	/* Offset: 0x000 Alternate Function Set Register0 		(R/W) */
	__IO u32  AFS1;    	/* Offset: 0x004 Alternate Function Set Register1 		(R/W) */
	__O  u32  AFC;    	/* Offset: 0x008 Alternate Function Clear Register0  	(W) 	*/
	u32 RESERVED0[15];
	__IO u32  ANAS;			/* Offset: 0x048 Analog function Set Register  				(R/W) */ 
	__O  u32  ANAC;			/* Offset: 0x04C Analog function Clear Register  			(W) 	*/ 
} AFIO_TypeDef;
	
/**
 * @brief EXTI
**/
typedef struct
{   
	__IO u32  IES;     	/* Offset: 0x000 Interrupt Enable Set Register  	 (R/W) */ 
	__O  u32  IEC;    	/* Offset: 0x004 Interrupt Enable Clear Register   (W)   */ 
	__IO u32  ITS;      /* Offset: 0x008 Interrupt Type Set Register0  		 (R/W) */ 
	__O  u32  ITC;      /* Offset: 0x00C Interrupt Type Clear Register0    (W)   */ 
	__IO u32  ITDS;	    /* Offset: 0x010 Interrupt Type Set Register1  		 (R/W) */ 
	__O  u32  ITDC;	    /* Offset: 0x014 Interrupt Type Clear Register1  	 (W)	  */ 
	__IO u32  PTS;      /* Offset: 0x018 Interrupt Polarity Set Register   (R/W) */ 
	__O  u32  PTC;   	  /* Offset: 0x01C Interrupt Polarity Clear Register (W)   */ 
	__IO u32  IF;	     	/* Offset: 0x020 Interrupt Status Register  			 (R/W) */
} EXTI_TypeDef;
	
	/** 
  * @brief TIM0&TIM1
  */
typedef struct	
{
	__IO u32 SR;            			 /*!< offset: 0x000 Interrupt status Register   (R/W)         */
	__IO u32 CR1;            			 /*!< offset: 0x004 Control Register            (R/W)         */
	__IO u32 ITARR;            	 /*!< offset: 0x008 Interrupt Repeat Timers     (R/W)         */
	__IO u32 ITCNT;            	 /*!< offset: 0x00C Interrupt Repeat Timers CNT (R/W)         */
	__IO u32 PSC;            		  	 /*!< offset: 0x010 Prescale Register           (R/W)         */
	u32  	RESERVED0;             			 /*!< DELETED!! offset: 0x014 Prescale Counter Register   (R/W)         */
	__IO u32 CNT;             			 /*!< offset: 0x018 Timer Counter Register      (R/W)         */
	__IO u32 CR2;            			 /*!< offset: 0x01C Match Control Register      (R/W)         */
	__IO u32 ARR;            			 /*!< offset: 0x020 Match Value Register0       (R/W)         */
	__IO u32 OCR1;            			 /*!< offset: 0x024 Match Value Register1       (R/W)         */	
	__IO u32 OCR2;            			 /*!< offset: 0x028 Match Value Register2       (R/W)         */
	__IO u32 OCR3;            		   /*!< offset: 0x02C Match Value Register3       (R/W)         */
	__IO u32 OCR4;             			 /*!< offset: 0x030 Match Value Register4       (R/W)         */
	__IO u32 CAPR;             			 /*!< offset: 0x034 Capture Control Register    (R/W)         */
	__IO u32 ICR1;            			 /*!< offset: 0x038 Capture Value Register1     (R/W)         */
	__IO u32 ICR2;            			 /*!< offset: 0x03C Capture Value Register2     (R/W)         */
	__IO u32 ICR3;            			 /*!< offset: 0x040 Capture Value Register3     (R/W)         */
	__IO u32 ICR4;            			 /*!< offset: 0x044 Capture Value Register4     (R/W)         */	
	__IO u32 OCMR;            			 /*!< offset: 0x048 Compare Output Register     (R/W)         */
	__IO u32 DT;             		   /*!< offset: 0x04C Death Time Register         (R/W)         */	
} TIM1_TypeDef;

/** 
  * @brief TIMx
  */
typedef struct
{
	__IO u32 SR;            			 /*!< offset: 0x000 Interrupt status Register   (R/W)         */
	__IO u32 CR1;            			 /*!< offset: 0x004 Control Register            (R/W)         */
	__IO u32 PSC;            		  	 /*!< offset: 0x008 Prescale Register           (R/W)         */
	u32  	RESERVED0;             			 /*!<DELETED!! offset: 0x00C Prescale Counter Register   (R/W)         */
	__IO u32 CNT;             			 /*!< offset: 0x010 Timer Counter Register      (R/W)         */
	__IO u32 CR2;            			 /*!< offset: 0x014 Match Control Register      (R/W)         */
	__IO u32 ARR;            			 /*!< offset: 0x018 Match Value Register0       (R/W)         */
} TIMx_TypeDef;

/** 
  * @brief RTC
  */
typedef struct
{
	__IO u32 CR;            	/*!< offset: 0x000 Control Register   (R/W)         */
	__IO u32 SR1;   		/*!< offset: 0x004 STATUS Register  (R/W)         */
	__IO u32 LOCK;  		/*!< offset: 0x008 Calendar lock Register           (R/W)         */
	__IO u32 CSEC;          	/*!< offset: 0x00C SEC Register   (R/W)         */
	__IO u32 CMIN;         	/*!< offset: 0x010 MIN Register      (R/W)         */
	__IO u32 CHOUR;        	/*!< offset: 0x014 HOUR Register      (R/W)         */
	__IO u32 CDAY;       	/*!< offset: 0x018 DAY Register       (R/W)         */
	__IO u32 CWEEK;       	/*!< offset: 0x01C WEEK Register       (R/W)         */
	__IO u32 CMONTH;     	/*!< offset: 0x020 MONTH Register       (R/W)         */
	__IO u32 CYEAR;        	/*!< offset: 0x024 YEAR Register       (R/W)         */
	__IO u32 IE;		           /*!< offset: 0x028  Interrupt Enable Register     (R/W)         */
	__IO u32 SR2;		           /*!< offset:  0x02C Interrupt Flag Register       (R/W)         */
	__IO u32 ASEC;	      	/*!< offset: 0x030   Alarm SEC Register       (R/W)         */
	__IO u32 AMIN;            	/*!< offset:  0x034 Alarm MIN Register      (R/W)         */
	__IO u32 AHOUR;           	/*!< offset: 0x038  Alarm HOUR Register     (R/W)         */
	__IO u32 TRIM;            	/*!< offset: 0x03C Compensate Register       (R/W)         */
} RTC_TypeDef;


/** 
  * @brief LCD
  */
typedef struct
{
	__IO u32 CR;            	/*!< offset: 0x000 Control Register   (R/W)         */
	__IO u32 GCR;   		/*!< offset: 0x004 Gray SET Register  (R/W)         */
	__IO u32 PSC;  		/*!< offset: 0x008 Display Frequency Control Register  (R/W)         */
	__IO u32 BTCR;          	/*!< offset: 0x00C Flashing Period Control Register   (R/W)         */
	__IO u32 BON;         	/*!< offset: 0x010 Flashing Light up Time Control Register      (R/W)         */
	__IO u32 PCR;        	/*!< offset: 0x014 Pin Enable Register      (R/W)         */
	u32  	RESERVED0;		/*!< Offset: 0x018 RESERVED0*/
	__IO u32 PDCR;       	/*!< offset: 0x01C  SEG/COM Select Register       (R/W)         */
	u32  	RESERVED1;		/*!< Offset: 0x020 RESERVED1*/
	__IO u32 PDTR;	/*!< offset: 0x024 Page Display Time Register       (R/W)         */
	__IO u32 SDPR;     	/*!< offset: 0x028 Maximum number of pages in rotation Register       (R/W)         */
	__IO u32 PNR;        	/*!< offset: 0x02C Current Carousel Display Page Register       (R/W)         */
  u32 RESERVED2[244];	
} LCD_TypeDef;

typedef struct
{
	__IO u32 LCD_PxLy[16*8];
}LCD_DATA_TypeDef;


/** 
  * @brief Independent WATCHDOG
  */
typedef struct
{
	__IO u32 RLR;   	/*!< IWDG Reload register,    Address offset: 0x00 */
	__I  u32 CNT; 	/*!< IWDG COUNT register,     Address offset: 0x04 */
	__IO u32 CR;    	/*!< IWDG Control register,   Address offset: 0x08 */
	__IO u32 KR;  	/*!< IWDG Status register,    Address offset: 0x0C */
	__IO u32 SR;   	/*!< IWDG Window register,    Address offset: 0x10 */
	u32 RESERVED0[251];        
	__IO u32 LOCK;    	/*!< IWDG Window register,    Address offset: 0x400 */		
} IWDG_TypeDef;

/** 
  * @brief UART 
  */
typedef struct	
{
	__IO u32 DR;     	/*!< Offset: 0x000 Buffer Register 		(R/W) */
	__IO u32 CR;		/*!< Offset: 0x004 Control Register		(R/W) */
	__IO u32 BRR;     	/*!< Offset: 0x008 Baud Rate Register		(R/W) */
	__IO u32 IE;    	/*!< Offset: 0x00C Interrupt Enable Register	(R/W) */
	__IO u32 SR;     	/*!< Offset: 0x010 Status Register		(R/W) */
	u32 RESERVED0;
	__IO u32 TO;   	/*!< Offset: 0x018 Time Out Register  		(R/W) */
	__IO u32 TXFR; 	/*!< Offset: 0x01C TX Buffer Reset Register  	(WO)  */
	__IO u32 RXFR;   	/*!< Offset: 0x020 RX Buffer Reset Register  	(WO)  */
	u32 RESERVED1;
	__IO u32 IRC;			/*!< Offset: 0x028 Infra-red Control Register  	(R/W) */	
	__IO u32 IRDC;		/*!< Offset: 0x02C IR TX PWM Control Register  	(R/W) */
} UART_TypeDef;

/** 
  * @brief Serial Peripheral Interface
  */
typedef struct		
{
	__IO u32 CR1;       /*!< SPI Control register 1                               Address offset: 0x00 */
	__IO u32 CR2;       /*!< SPI Control register 2,                              Address offset: 0x04 */
	__IO u32 DR;        	/*!< SPI data register,                                   Address offset: 0x08 */
	__IO u32 SR1;        	/*!< SPI Status register,                                 Address offset: 0x0C */	
	__IO u32 BR; 	/*!< SPI Clock prescaler register                         Address offset: 0x10 */
	__IO u32 IE;        	/*!< SPI Interrupt ENABLE register                        Address offset: 0x14 */	
	__IO u32 SR2;       	/*!< SPI Interrupt Raw Int Status register                Address offset: 0x18 */	
	u32 RESERVED0;
	__IO u32 IFC;       	/*!< SPI Interrupt Clear Register register                Address offset: 0x20 */	
	u32 RESERVED1;	/*0X24*/
	__IO u32 CSS;      /*!< SPI Chip-Select Control register                     Address offset: 0x28*/	
} SPI_TypeDef;

/** 
  * @brief Inter-integrated Circuit Interface
  */
typedef struct
{
	__IO u32 CR;		/*!< I2C Control Set register ,         Address offset: 0x00 */
	__I  u32 SR; 		/*!< I2C status register,               Address offset: 0x04 */
	__IO u32 DR;  	/*!< I2C data register,                 Address offset: 0x08 */	
	__IO u32 OAR;	/*!< I2C Own address register,          Address offset: 0x0C */
	__IO u32 RESERVED0; /*!< RESERVED0,      Address offset: 0x10*/	
	__IO u32 RESERVED1; /*!< RESERVED0,      Address offset: 0x14 */	
	__IO u32 CCR; 		/*!< I2C Control Reset register 2,      Address offset: 0x18 */	
} I2C_TypeDef;

/** 
  * @brief  ADC  	  
  */
typedef struct
{
	__IO u32 CR;       	/*!< Offset: 0x000 ADC Control register */
	__IO u32 SR;    	/*!< Offset: 0x004 ADC Status Register  (R/W) */
	__IO u32 DR;    	/*!< Offset: 0x008 ADC data register (R/W) */
	__IO u32 SAMPLE;	/*!< Offset: 0x00C ADC SAMPLE TIMER register (R/W) */
} ADC_TypeDef;	

/** 
  * @brief  DAC  	  
  */
typedef struct
{
	__IO u32 CR;       	/*!< Offset: 0x000 DAC Control register */
	__IO u32 DR;    	/*!< Offset: 0x004 DAC Data Register  (R/W) */
	__IO u32 IE;    	/*!< Offset: 0x008 DAC Interrupt register (R/W) */
	__IO u32 SR;	/*!< Offset: 0x00C DAC  Sata register (R/W) */
} DAC_TypeDef;	


/** 
  * @brief CMP
  */
typedef struct
{
	__IO u32 CR1;       /*!< Comparator Control register1                         Address offset: 0x00 */
	__IO u32 CR2;       /*!< Comparator Control register2                         Address offset: 0x04 */
		u32 RESERVED0[1];
	__IO u32 IE;        /*!< Interrupt ENABLE register                            Address offset: 0x0C */	
	__IO u32 SR;       /*!< Interrupt Int Status register                        Address offset: 0x10 */
} CMP_TypeDef;

/** 
  * @brief OPA
  */
typedef struct
{
	__IO u32 CR1;       /*!< Comparator Control register1                         Address offset: 0x00 */
	__IO u32 CR2;       /*!< Comparator Control register2                         Address offset: 0x04 */
} OPA_TypeDef;


typedef struct
{
	__IO u32 DR;       /*!< 5Bit DAC data register                               Address offset: 0x08 */
} LDAC_TypeDef;

/**
 * @brief Cyclic Redundancy Check
 */
typedef struct
{                                                                              
	__IO u32 CR;               /*!< 0x000 CRC Control Register                                           */
	__IO u32 SEED;              /*!< 0x004 CRC Seed Register                                              */	
	__IO u32 POLY;             /*!< 0x008 CRC polynomial Register                                        */
	__IO u32 DIN;              /*!< 0x00C CRC Data INPUT Register                                        */
	__IO u32 DOUT;             /*!< 0x010 CRC Data INPUT Register                                        */
} CRC_TypeDef;


/**
 * @brief PWR
 */
typedef struct 
{
	__IO u32 PVDR;	/*!< Offset: 0x000 VDD Low Voltage Detect Control Register (R/W) */
	u32 RESERVED0[11];
	__IO u32 VRFR;	/*!< Offset: 0x030 32KHZ IOSC Control Register 2 (R/W) */
}  PWR_TypeDef;

/**
 * @brief RCC
 */
typedef struct 
{
	__IO u32 HSECR1;  	/*!< Offset: 0x008 Crystal Control Register1 (R/W) */
	__IO u32 HSECR2;  	/*!< Offset: 0x00C Crystal Control Register2 (R/W) */
	__IO u32 HSICR;	/*!< Offset: 0x010 24MHZ IOSC Control Register (R/W) */
	__IO u32 LSICR;	/*!< Offset: 0x014 32KHZ IOSC Control Register (R/W) */
	__IO u32 PCR;       	 	/*!< Offset: 0x018 Frequency Doubling Control Register (R/W) */
	u32 RESERVED0[2];  	/*!< Offset: 0x020 GPIO HighSink Control Register (R/W) */
	__IO u32 MCOR;	/*!< Offset: 0x024 MCO Frequency Division Control Register (R/W) */
	__IO u32 LSECR1;	/*!< Offset: 0x028 32KHZ IOSC Control Register 1 (R/W) */
	__IO u32 LSECR2;	/*!< Offset: 0x02C 32KHZ IOSC Control Register 2 (R/W) */
	u32 RESERVED1[30199];/*<Offset:0x1830-0x1F008*/
	__IO u32 CFGR;	/*!< Offset: 0x1F00C*/
	__IO u32 RSR;	/*!< Offset: 0x1F010*/
	__IO u32 HSFRR;	/*!< Offset: 0x1F014*/
	__IO u32 RCR;	/*!< Offset: 0x1F018*/
}  RCC_TypeDef;


/** 
  * @brief IFMC  
  */
typedef struct
{
	__IO u32 CR; 	/*!< Offset: 0x000 Flash Command Register (R/W) */
	__IO u32 SR;   	/*!< Offset: 0x004 Flash Interrupt status Register (R/W) */
	__IO u32 IE;  	/*!< Offset: 0x008 Flash Interrupt Enable Register  (R/W) */
	__IO u32 AR;    	/*!< Offset: 0x00C Flash Address Register (R/W) */
	__IO u32 DR;  	/*!< Offset: 0x010 Flash Programming Data Register0  (R/W) */
	u32  RESERVED0[5];
	__IO u32 PSC;  	/*!< Offset: 0x028 Flash Erase Clock Division Register  (R/W) */
	u32  RESERVED1[31733];
	__IO u32 BSR;  	/*!< Offset: 0x1F000 BOOT Status Register  (R/W) */
	u32  RESERVED2[8];
	__IO u32 RPT;  	/*!< Offset: 0x1F024 READ Protect Register  (R/W) */
} IFMC_TypeDef;	


/** 
  * @brief Beep
  */
typedef struct
{
  __IO u32 HCR;  /*< BEEP Current Control register, Address 0x40001820 */
	u32  RESERVED1[1015];
	__IO u32 CR;    /*!< BEEP Control register,   Address offset: 0x1000 */
} BEEP_TypeDef;


/*Peripheral and SRAM base address */
#define SRAM_BASE             (0x20000000)     /*!< (SRAM      ) Base Address */
#define FLASH_BASE            (0x00000000)     /*!< (FLASH      ) Base Address */

#define APB_BASE              (0x40000000)
#define AHB_BASE              (0x48000000)

/* AHB peripherals */
#define GPIOA_BASE               (AHB_BASE + 0x00000000)
#define GPIOB_BASE               (AHB_BASE + 0x00001000)
#define GPIOC_BASE               (AHB_BASE + 0x00002000)
#define GPIOD_BASE               (AHB_BASE + 0x00003000)

#define EXTIA_BASE	(AHB_BASE + 0x0000001C)
#define EXTIB_BASE	(AHB_BASE + 0x0000101C)
#define EXTIC_BASE	(AHB_BASE + 0x0000201C)
#define EXTID_BASE	(AHB_BASE + 0x0000301C)

#define AFIOA_BASE	(AHB_BASE + 0x00000010)
#define AFIOB_BASE	(AHB_BASE + 0x00001010)
#define AFIOC_BASE	(AHB_BASE + 0x00002010)
#define AFIOD_BASE	(AHB_BASE + 0x00003010)

/* APB peripherals */
#define IFMC_BASE    	    (APB_BASE + 0x00000000)
#define CMP0_BASE	        (APB_BASE + 0x00000800)
#define CMP1_BASE	        (APB_BASE + 0x00000C00)
#define OPA0_BASE	        (APB_BASE + 0x00000800)
#define OPA1_BASE       	(APB_BASE + 0x00000C00)
#define LDAC0_BASE	      (APB_BASE + 0x00000808)
#define LDAC1_BASE	      (APB_BASE + 0x00000C08)
#define TIM2_BASE       	(APB_BASE + 0x00001000)
#define TIM3_BASE       	(APB_BASE + 0x00001400)
#define RCC_BASE     	    (APB_BASE + 0x00001808)
#define PWR_BASE        	(APB_BASE + 0x00001800)
#define TIM4_BASE        	(APB_BASE + 0x00001C00)
#define SWDG_BASE  	      (APB_BASE + 0x00002000)
#define BEEP_BASE         (APB_BASE + 0x00001820)
#define IWDG_BASE       	(APB_BASE + 0x00003000)
#define SPI1_BASE        	(APB_BASE + 0x00003800)
#define CRC_BASE         	(APB_BASE + 0x00003C00)
#define UART0_BASE    	  (APB_BASE + 0x00004400)
#define I2C_BASE          (APB_BASE + 0x00005400)
#define ADC_BASE          (APB_BASE + 0x00012400)
#define TIM0_BASE		      (APB_BASE + 0x00012800)
#define TIM1_BASE        	(APB_BASE + 0x00012C00)
#define SPI0_BASE         (APB_BASE + 0x00013000)
#define UART1_BASE   	  	(APB_BASE + 0x00013800)
#define RTC_BASE   	    	(APB_BASE + 0x00013C00)
#define DAC_BASE		    	(APB_BASE + 0x00014000)
#define LCD_BASE		    	(APB_BASE + 0x00015000)
#define LCD_DATA_BASE	    (APB_BASE + 0x00015400)
#define ID_BASE		        (APB_BASE + 0x0001F020)


/**
  * @}
  */


/** @addtogroup Peripheral_declaration
  * @{
  */  
	
#define PWR	((PWR_TypeDef   *) PWR_BASE )
#define RCC	((RCC_TypeDef   *) RCC_BASE )
#define ID		((ID_TypeDef       *) ID_BASE )

#define GPIOA		((GPIO_TypeDef     *) GPIOA_BASE )
#define GPIOB		((GPIO_TypeDef     *) GPIOB_BASE )
#define GPIOC		((GPIO_TypeDef     *) GPIOC_BASE )
#define GPIOD		((GPIO_TypeDef     *) GPIOD_BASE )

#define AFIOA	((AFIO_TypeDef     *)AFIOA_BASE)
#define AFIOB	((AFIO_TypeDef     *)AFIOB_BASE)
#define AFIOC	((AFIO_TypeDef     *)AFIOC_BASE)
#define AFIOD	((AFIO_TypeDef     *)AFIOD_BASE)

#define EXTIA	((EXTI_TypeDef     *) EXTIA_BASE )
#define EXTIB	((EXTI_TypeDef     *) EXTIB_BASE )
#define EXTIC	((EXTI_TypeDef     *) EXTIC_BASE )
#define EXTID	((EXTI_TypeDef     *) EXTID_BASE )

#define UART0 ((UART_TypeDef     *) UART0_BASE )

#define IFMC	((IFMC_TypeDef    *) IFMC_BASE )
#define ADC   ((ADC_TypeDef      *) ADC_BASE )

#define I2C	((I2C_TypeDef      *) I2C_BASE )

#define SPI0  ((SPI_TypeDef      *) SPI0_BASE )
#define SPI1	((SPI_TypeDef      *) SPI1_BASE )

#define CMP0			((CMP_TypeDef   *) CMP0_BASE )
#define CMP1			((CMP_TypeDef   *) CMP1_BASE )

#define OPA0			((OPA_TypeDef   *) OPA0_BASE )
#define OPA1			((OPA_TypeDef   *) OPA1_BASE )

#define LDAC0			((LDAC_TypeDef   *) LDAC0_BASE )
#define LDAC1			((LDAC_TypeDef   *) LDAC1_BASE )

#define TIM0			((TIM1_TypeDef      *) TIM0_BASE )
#define TIM1			((TIM1_TypeDef      *) TIM1_BASE )

#define TIM2			((TIMx_TypeDef      *) TIM2_BASE )
#define TIM3			((TIMx_TypeDef      *) TIM3_BASE )
#define TIM4			((TIMx_TypeDef      *) TIM4_BASE )

#define CRC				((CRC_TypeDef      *) CRC_BASE )
#define IWDG			((IWDG_TypeDef      *) IWDG_BASE )
#define SWDG			((IWDG_TypeDef      *) SWDG_BASE )

#define RTC				((RTC_TypeDef      *) RTC_BASE )
#define DAC				((DAC_TypeDef      *) DAC_BASE )
#define LCD				((LCD_TypeDef      *) LCD_BASE )
#define LCD_DATA		((LCD_DATA_TypeDef      *) LCD_DATA_BASE )

#define BEEP      ((BEEP_TypeDef     *) BEEP_BASE )

/**
  * @}
  */



  /** @addtogroup Peripheral_Registers_Bits_Definition
  * @{
  */
    
/******************************************************************************/
/*                         Peripheral Registers Bits Definition               */
/******************************************************************************/

/********************  Bits definition for RCC register  ******************/
#define RCC_HSECR1_EN               ((u32)0x00000001)        /*!<  */
#define RCC_HSECR1_AAC              ((u32)0x00000002)        /*!<  */
#define RCC_HSECR1_ECEN             ((u32)0x00000004)        /*!<  */
#define RCC_HSECR1_HSE2D            ((u32)0x00000008)        /*!<  */
#define RCC_HSECR1_HSEFR            ((u32)0x00000010)        /*!<  */
#define RCC_HSECR1_LPF              ((u32)0x00000300)        /*!<  */
#define RCC_HSECR1_LPFB             ((u32)0x00000400)        /*!<  */
#define RCC_HSECR1_RDY              ((u32)0x80000000)        /*!<  */

/******************************************************************************/
#define RCC_HSECR2_CAD              ((u32)0x00000007)        /*!<  */
#define RCC_HSECR2_CS               ((u32)0x00000070)        /*!<  */
#define RCC_HSECR2_FDR              ((u32)0x00000300)        /*!<  */
#define RCC_HSICR_EN                ((u32)0x00000001)        /*!<  */
#define RCC_LSICR_EN                ((u32)0x00000001)        /*!<  */
#define RCC_PCR_EN                  ((u32)0x00000001)        /*!<  */
#define RCC_MCOR_COPRE              ((u32)0x00000007)        /*!<  */
#define RCC_LSECR1_EN               ((u32)0x00000001)        /*!<  */
#define RCC_LSECR1_ECEN             ((u32)0x00000002)        /*!<  */
#define RCC_LSECR1_LPF              ((u32)0x00000300)        /*!<  */
#define RCC_LSECR1_LPFB             ((u32)0x00000400)        /*!<  */
#define RCC_LSECR1_CRA              ((u32)0x000F0000)        /*!<  */
#define RCC_LSECR1_CFA              ((u32)0x00F00000)        /*!<  */
#define RCC_LSECR1_CS               ((u32)0x0F000000)        /*!<  */
#define RCC_LSECR1_RDY              ((u32)0x80000000)        /*!<  */
#define RCC_LSECR2_CAD              ((u32)0x0000000F)        /*!<  */
#define RCC_LSECR2_FDR              ((u32)0x00000030)        /*!<  */

/********************  Bits definition for RCC_CFGR register  ******************/
#define RCC_CFGR_SCW                  ((u32)0x00000003)       	 /*!<  */
#define RCC_CFGR_PLLSRC               ((u32)0x0000000C)        /*!<  */
#define RCC_CFGR_HPRE                 ((u32)0x00000070)        /*!<  */
#define RCC_CFGR_PPRE                 ((u32)0x00000700)        /*!<  */
#define RCC_CFGR_HSEDE                ((u32)0x00001000)        /*!<  */
#define RCC_CFGR_HSEF                 ((u32)0x00002000)        /*!<  */
#define RCC_CFGR_PLLDE                ((u32)0x00004000)        /*!<  */
#define RCC_CFGR_PLLF                 ((u32)0x00008000)        /*!<  */
#define RCC_CFGR_WKDL                 ((u32)0x00030000)        /*!<  */
#define RCC_CFGR_WKCK                 ((u32)0x00100000)        /*!<  */

/********************  Bits definition for RCC_RSR register  ******************/
#define RCC_RSR_SFR                   ((u32)0x00000001)        /*!<  */
#define RCC_RSR_IWDGR                 ((u32)0x00000002)        /*!<  */
#define RCC_RSR_SWDG                  ((u32)0x00000010)        /*!<  */
#define RCC_RSR_HSCR                  ((u32)0x00000020)        /*!<  */
#define RCC_RSR_PLLR                  ((u32)0x00000040)        /*!<  */
#define RCC_RSR_POR                   ((u32)0x00000080)        /*!<  */
#define RCC_RSR_PINR                  ((u32)0x00000100)        /*!<  */
#define RCC_RSR_PVDR                  ((u32)0x00000200)        /*!<  */
#define RCC_RSR_LDOR                  ((u32)0x00000400)        /*!<  */

/********************  Bits definition for RCC_HSFRR register  ******************/
#define RCC_HSFRR                     ((u32)0x0000FFFF)        /*!<  */
#define RCC_HSFRR_KEY                 ((u32)0x0000AB56)        /*!<  */

/********************  Bits definition for RCC_RCR register  ******************/
#define RCC_RCR_OREN                  ((u32)0x00000010)        /*!<  */
#define RCC_RCR_PREN                  ((u32)0x00000020)        /*!<  */
#define RCC_RCR_BGREN                 ((u32)0x00000040)        /*!<  */
#define RCC_RCR_PDRE                  ((u32)0x00000100)        /*!<  */
#define RCC_RCR_LDORE                 ((u32)0x00000200)        /*!<  */
#define RCC_RCR_HREN                  ((u32)0x00000400)        /*!<  */

/******************************************************************************/
/********************  Bits definition for PWR_VDDLVDCTRL register  ******************/
#define PWR_PVDR_EN                         ((u32)0x00000001)        /*!<  */
#define PWR_PVDR_PLS                        ((u32)0x0000000E)        /*!<  */
#define PWR_VRFR_EN                         ((u32)0x00000001)        /*!<  */


/******************************************************************************/
/*                                                                            */
/*                                      DAC                                */
/*                                                                            */
/******************************************************************************/
#define DAC_IE_EOCE			0x00000001
#define DAC_SR_EOC	0x00000001
/******************************************************************************/
/*                                                                            */
/*                                      AFIO                                  */
/*                                                                            */
/******************************************************************************/
#define AFIO_Pin_0                 ((u16)0x0001)  /* Pin 0 selected    */
#define AFIO_Pin_1                 ((u16)0x0002)  /* Pin 1 selected    */
#define AFIO_Pin_2                 ((u16)0x0004)  /* Pin 2 selected    */
#define AFIO_Pin_3                 ((u16)0x0008)  /* Pin 3 selected    */
#define AFIO_Pin_4                 ((u16)0x0010)  /* Pin 4 selected    */
#define AFIO_Pin_5                 ((u16)0x0020)  /* Pin 5 selected    */
#define AFIO_Pin_6                 ((u16)0x0040)  /* Pin 6 selected    */
#define AFIO_Pin_7                 ((u16)0x0080)  /* Pin 7 selected    */
#define AFIO_Pin_8                 ((u16)0x0100)  /* Pin 8 selected    */
#define AFIO_Pin_9                 ((u16)0x0200)  /* Pin 9 selected    */
#define AFIO_Pin_10                ((u16)0x0400)  /* Pin 10 selected   */
#define AFIO_Pin_11                ((u16)0x0800)  /* Pin 11 selected   */
#define AFIO_Pin_12                ((u16)0x1000)  /* Pin 12 selected   */
#define AFIO_Pin_13                ((u16)0x2000)  /* Pin 13 selected   */
#define AFIO_Pin_14                ((u16)0x4000)  /* Pin 14 selected   */
#define AFIO_Pin_15                ((u16)0x8000)  /* Pin 15 selected   */
#define AFIO_Pin_All               ((u16)0xFFFF)  /* All pins selected */
#define AFIO_AF_None	       ((u8)0x00)
#define AFIO_AF_0            ((u8)0x01)	/** @brief  AF 0 selection **/
#define AFIO_AF_1            ((u8)0x02)	/** @brief  AF 1 selection **/
#define AFIO_AF_2            ((u8)0x03)	/** @brief  AF 2 selection **/
#define AFIO_AF_3            ((u8)0x04)	/** @brief  AF 3 selection **/
#define AFIO_AF_4            ((u8)0x05)	/** @brief  AF 4 selection **/
#define AFIO_AF_5            ((u8)0x06)	/** @brief  AF 5 selection **/
#define AFIO_AF_6            ((u8)0x07)	/** @brief  AF 6 selection **/
/****************** Bit definition for AFIO_AFS0 register  ********************/
#define AFIO_AFS0_IO0            ((u32)0x0000000F)
#define AFIO_AFS0_IO1            ((u32)0x000000F0)
#define AFIO_AFS0_IO2            ((u32)0x00000F00)
#define AFIO_AFS0_IO3            ((u32)0x0000F000)
#define AFIO_AFS0_IO4            ((u32)0x000F0000)
#define AFIO_AFS0_IO5            ((u32)0x00F00000)
#define AFIO_AFS0_IO6            ((u32)0x0F000000)
#define AFIO_AFS0_IO7            ((u32)0xF0000000)
/****************** Bit definition for AFIO_AFS1 register  ********************/
#define AFIO_AFS1_IO8             ((u32)0x0000000F)
#define AFIO_AFS1_IO9             ((u32)0x000000F0)
#define AFIO_AFS1_IO10            ((u32)0x00000F00)
#define AFIO_AFS1_IO11            ((u32)0x0000F000)
#define AFIO_AFS1_IO12            ((u32)0x000F0000)
#define AFIO_AFS1_IO13            ((u32)0x00F00000)
#define AFIO_AFS1_IO14            ((u32)0x0F000000)
#define AFIO_AFS1_IO15            ((u32)0xF0000000)
/*******************  Bit definition for AFIO_AFC register  *******************/
#define AFIO_AFC_BIT0                        ((u16)0x0001)                 /* Port alternate function bit reset, bit 0 */
#define AFIO_AFC_BIT1                        ((u16)0x0002)                 /* Port alternate function bit reset, bit 1 */
#define AFIO_AFC_BIT2                        ((u16)0x0004)                 /* Port alternate function bit reset, bit 2 */
#define AFIO_AFC_BIT3                        ((u16)0x0008)                 /* Port alternate function bit reset, bit 3 */
#define AFIO_AFC_BIT4                        ((u16)0x0010)                 /* Port alternate function bit reset, bit 4 */
#define AFIO_AFC_BIT5                        ((u16)0x0020)                 /* Port alternate function bit reset, bit 5 */
#define AFIO_AFC_BIT6                        ((u16)0x0040)                 /* Port alternate function bit reset, bit 6 */
#define AFIO_AFC_BIT7                        ((u16)0x0080)                 /* Port alternate function bit reset, bit 7 */
#define AFIO_AFC_BIT8                        ((u16)0x0100)                 /* Port alternate function bit reset, bit 8 */
#define AFIO_AFC_BIT9                        ((u16)0x0200)                 /* Port alternate function bit reset, bit 9 */
#define AFIO_AFC_BIT10                       ((u16)0x0400)                 /* Port alternate function bit reset, bit 10*/
#define AFIO_AFC_BIT11                       ((u16)0x0800)                 /* Port alternate function bit reset, bit 11*/
#define AFIO_AFC_BIT12                       ((u16)0x1000)                 /* Port alternate function bit reset, bit 12*/
#define AFIO_AFC_BIT13                       ((u16)0x2000)                 /* Port alternate function bit reset, bit 13*/
#define AFIO_AFC_BIT14                       ((u16)0x4000)                 /* Port alternate function bit reset, bit 14*/
#define AFIO_AFC_BIT15                       ((u16)0x8000)                 /* Port alternate function bit reset, bit 15*/
/*******************  Bit definition for AFIO_ANAS register  *******************/                                             
#define AFIO_ANAS_BIT0                        ((u16)0x0001)               /* Port analog function bit set, bit 0 */   
#define AFIO_ANAS_BIT1                        ((u16)0x0002)               /* Port analog function bit set, bit 1 */   
#define AFIO_ANAS_BIT2                        ((u16)0x0004)               /* Port analog function bit set, bit 2 */   
#define AFIO_ANAS_BIT3                        ((u16)0x0008)               /* Port analog function bit set, bit 3 */   
#define AFIO_ANAS_BIT4                        ((u16)0x0010)               /* Port analog function bit set, bit 4 */   
#define AFIO_ANAS_BIT5                        ((u16)0x0020)               /* Port analog function bit set, bit 5 */   
#define AFIO_ANAS_BIT6                        ((u16)0x0040)               /* Port analog function bit set, bit 6 */   
#define AFIO_ANAS_BIT7                        ((u16)0x0080)               /* Port analog function bit set, bit 7 */  
#define AFIO_ANAS_BIT8                        ((u16)0x0100)               /* Port analog function bit set, bit 8 */   
#define AFIO_ANAS_BIT9                        ((u16)0x0200)               /* Port analog function bit set, bit 9 */   
#define AFIO_ANAS_BIT10                       ((u16)0x0400)               /* Port analog function bit set, bit 10*/   
#define AFIO_ANAS_BIT11                       ((u16)0x0800)               /* Port analog function bit set, bit 11*/   
#define AFIO_ANAS_BIT12                       ((u16)0x1000)               /* Port analog function bit set, bit 12*/   
#define AFIO_ANAS_BIT13                       ((u16)0x2000)               /* Port analog function bit set, bit 13*/   
#define AFIO_ANAS_BIT14                       ((u16)0x4000)               /* Port analog function bit set, bit 14*/   
#define AFIO_ANAS_BIT15                       ((u16)0x8000)               /* Port analog function bit set, bit 15*/                                                                                                                                
/*******************  Bit definition for AFIO_ANAC register  *******************/                                             
#define AFIO_ANAC_BIT0                        ((u16)0x0001)               /* Port analog function bit reset, bit 0 */   
#define AFIO_ANAC_BIT1                        ((u16)0x0002)               /* Port analog function bit reset, bit 1 */   
#define AFIO_ANAC_BIT2                        ((u16)0x0004)               /* Port analog function bit reset, bit 2 */   
#define AFIO_ANAC_BIT3                        ((u16)0x0008)               /* Port analog function bit reset, bit 3 */   
#define AFIO_ANAC_BIT4                        ((u16)0x0010)               /* Port analog function bit reset, bit 4 */   
#define AFIO_ANAC_BIT5                        ((u16)0x0020)               /* Port analog function bit reset, bit 5 */   
#define AFIO_ANAC_BIT6                        ((u16)0x0040)               /* Port analog function bit reset, bit 6 */   
#define AFIO_ANAC_BIT7                        ((u16)0x0080)               /* Port analog function bit reset, bit 7 */  
#define AFIO_ANAC_BIT8                        ((u16)0x0100)               /* Port analog function bit reset, bit 8 */   
#define AFIO_ANAC_BIT9                        ((u16)0x0200)               /* Port analog function bit reset, bit 9 */   
#define AFIO_ANAC_BIT10                       ((u16)0x0400)               /* Port analog function bit reset, bit 10*/   
#define AFIO_ANAC_BIT11                       ((u16)0x0800)               /* Port analog function bit reset, bit 11*/   
#define AFIO_ANAC_BIT12                       ((u16)0x1000)               /* Port analog function bit reset, bit 12*/   
#define AFIO_ANAC_BIT13                       ((u16)0x2000)               /* Port analog function bit reset, bit 13*/   
#define AFIO_ANAC_BIT14                       ((u16)0x4000)               /* Port analog function bit reset, bit 14*/   
#define AFIO_ANAC_BIT15                       ((u16)0x8000)               /* Port analog function bit reset, bit 15*/ 

/******************************************************************************/
/*                                                                            */
/*                                     EXTI                                   */
/*                                                                            */
/******************************************************************************/
#define EXTI_Pin_0		((u16)0x0001)		/* Pin 0 selected    */
#define EXTI_Pin_1		((u16)0x0002)		/* Pin 1 selected    */
#define EXTI_Pin_2		((u16)0x0004)		/* Pin 2 selected    */
#define EXTI_Pin_3		((u16)0x0008)		/* Pin 3 selected    */
#define EXTI_Pin_4		((u16)0x0010)		/* Pin 4 selected    */
#define EXTI_Pin_5		((u16)0x0020)		/* Pin 5 selected    */
#define EXTI_Pin_6		((u16)0x0040)		/* Pin 6 selected    */
#define EXTI_Pin_7		((u16)0x0080)		/* Pin 7 selected    */
#define EXTI_Pin_8		((u16)0x0100)		/* Pin 8 selected    */
#define EXTI_Pin_9		((u16)0x0200)		/* Pin 9 selected    */
#define EXTI_Pin_10		((u16)0x0400)		/* Pin 10 selected   */
#define EXTI_Pin_11		((u16)0x0800)		/* Pin 11 selected   */
#define EXTI_Pin_12		((u16)0x1000)		/* Pin 12 selected   */
#define EXTI_Pin_13		((u16)0x2000)		/* Pin 13 selected   */
#define EXTI_Pin_14		((u16)0x4000)		/* Pin 14 selected   */
#define EXTI_Pin_15		((u16)0x8000)		/* Pin 15 selected   */
#define EXTI_Pin_All	((u16)0xFFFF)		/* All pins selected */
#define EXTI_IT_0	  	((u16)0x0001)		/* Port interrupt selected 0 */
#define EXTI_IT_1	   	((u16)0x0002)		/* Port interrupt selected 1 */
#define EXTI_IT_2	  	((u16)0x0004)		/* Port interrupt selected 2 */
#define EXTI_IT_3		  ((u16)0x0008)		/* Port interrupt selected 3 */
#define EXTI_IT_4	  	((u16)0x0010)		/* Port interrupt selected 4 */
#define EXTI_IT_5		  ((u16)0x0020)		/* Port interrupt selected 5 */
#define EXTI_IT_6		  ((u16)0x0040)		/* Port interrupt selected 6 */
#define EXTI_IT_7		  ((u16)0x0080)		/* Port interrupt selected 7 */
#define EXTI_IT_8	  	((u16)0x0100)		/* Port interrupt selected 8 */
#define EXTI_IT_9		  ((u16)0x0200)		/* Port interrupt selected 9 */
#define EXTI_IT_10		((u16)0x0400)		/* Port interrupt selected 10 */
#define EXTI_IT_11		((u16)0x0800)		/* Port interrupt selected 11 */
#define EXTI_IT_12		((u16)0x1000)		/* Port interrupt selected 12 */
#define EXTI_IT_13		((u16)0x2000)		/* Port interrupt selected 13 */
#define EXTI_IT_14		((u16)0x4000)		/* Port interrupt selected 14 */
#define EXTI_IT_15		((u16)0x8000)		/* Port interrupt selected 15 */
#define EXTI_IT_All		((u16)0xFFFF)		/* Port interrupt selected All */
/********************  Bits definition for EXTI_IF register  ******************/
#define EXTI_IF_BIT0                        ((u16)0x0001)                 /*  ⲿжϱ־λ, bit 0 */
#define EXTI_IF_BIT1                        ((u16)0x0002)                 /*  ⲿжϱ־λ, bit 1 */
#define EXTI_IF_BIT2                        ((u16)0x0004)                 /*  ⲿжϱ־λ, bit 2 */
#define EXTI_IF_BIT3                        ((u16)0x0008)                 /*  ⲿжϱ־λ, bit 3 */
#define EXTI_IF_BIT4                        ((u16)0x0010)                 /*  ⲿжϱ־λ, bit 4 */
#define EXTI_IF_BIT5                        ((u16)0x0020)                 /*  ⲿжϱ־λ, bit 5 */
#define EXTI_IF_BIT6                        ((u16)0x0040)                 /*  ⲿжϱ־λ, bit 6 */
#define EXTI_IF_BIT7                        ((u16)0x0080)                 /*  ⲿжϱ־λ, bit 7 */
#define EXTI_IF_BIT8                        ((u16)0x0100)                 /*  ⲿжϱ־λ, bit 8 */
#define EXTI_IF_BIT9                        ((u16)0x0200)                 /*  ⲿжϱ־λ, bit 9 */
#define EXTI_IF_BIT10                       ((u16)0x0400)                 /*  ⲿжϱ־λ, bit 10*/
#define EXTI_IF_BIT11                       ((u16)0x0800)                 /*  ⲿжϱ־λ, bit 11*/
#define EXTI_IF_BIT12                       ((u16)0x1000)                 /*  ⲿжϱ־λ, bit 12*/
#define EXTI_IF_BIT13                       ((u16)0x2000)                 /*  ⲿжϱ־λ, bit 13*/
#define EXTI_IF_BIT14                       ((u16)0x4000)                 /*  ⲿжϱ־λ, bit 14*/
#define EXTI_IF_BIT15                       ((u16)0x8000)                 /*  ⲿжϱ־λ, bit 15*/

/******************************************************************************/
/*                                                                            */
/*                      IFMC Registers                      */
/*                                                                            */
/******************************************************************************/

/*******************  Bit definition for IFMC_ACR register  ******************/
#define  IFMC_CR_START   		      ((u32)0x00000001)        /*!< IFMC */
#define  IFMC_CR_CMD              ((u32)0x00000006)        /*!< IFMC */
#define  IFMC_CR_WAIT             ((u32)0x00000020)        /*!< IFMCʵȴ */
#define  IFMC_CR_MODE       	    ((u32)0x00000100)        /*!< IFMCдʷʽ */
#define  IFMC_CR_AINC             ((u32)0x00002000)        /*!< IFMCַԶ */

/*******************  Bit definition for IFMC_ISR register  ******************/
																																								
#define  IFMC_SR_WOV                     ((u32)0x00000001)        /*!< д */
#define  IFMC_SR_POV                     ((u32)0x00000002)        /*!<  */
#define  IFMC_SR_COV                     ((u32)0x00000004)        /*!< IFMCⱣʱ(KEY=0xAD) */
#define  IFMC_SR_BUSY                    ((u32)0x00000008)        /*!< IFMCæ־ */
#define  IFMC_SR_CERR                    ((u32)0x00000010)        /*!< IFMC־ */
#define  IFMC_SR_KERR                    ((u32)0x00000020)        /*!< IFMC־ */
#define  IFMC_SR_AERR                    ((u32)0x00000040)        /*!< IFMCַ־ */

/*******************  Bit definition for IFMC_IER register  ******************/
																																								
#define  IFMC_IE_WOVI                   ((u32)0x00000001)        /*!< джʹ */
#define  IFMC_IE_POVI                   ((u32)0x00000002)        /*!< жʹ  */
#define  IFMC_IE_COVI                   ((u32)0x00000004)        /*!< IFMCⱣʱжʹ (KEY=0xAD) */
#define  IFMC_IE_CERI                   ((u32)0x00000010)        /*!< IFMCжʹ */
#define  IFMC_IE_KERI                   ((u32)0x00000020)        /*!< IFMCжʹ */
#define  IFMC_IE_AERI                   ((u32)0x00000040)        /*!< IFMCַжʹ */

/*******************  Bit definition for IFMC_AR register  ******************/

/*******************  Bit definition for IFMC_AR register  *******************/
#define  IFMC_AR_AR                        ((u32)0x0000FFFC)        /*!< Flash Address */

/*******************  Bit definition for IFMC_DR register  *******************/
#define  IFMC_DR_DR                        ((u32)0xFFFFFFFF)        /*!< Flash Address */

/*******************  Bit definition for IFMC_DIV register  *******************/
#define  IFMC_PSC_PSC                      ((u32)0x000000FF)        /*!< Flash Address */

/********************  Bits definition for IFMC_BSR register  ******************/
#define  IFMC_BSR_BSR                      ((u32)0x00000001)        /*  */

/********************  Bits definition for IFMC_RPT register  ******************/
#define  IFMC_RPT_PSR                      ((u32)0x00000001)        /*  */

/******************************************************************************/
/*                                                                            */
/*      Universal Asynchronous Receiver Transmitter (UART)       */
/*                                                                            */
/******************************************************************************/
/******************  Bit definition for UART_BR register  *******************/
#define  UART_DR                          ((u16)0x01FF)               /*!< BR[8:0] bits (Receiver Transmitter Buffer value) */

/******************  Bit definition for UART_CR register  *******************/
#define  UART_CR_WP                        ((u32)0x00000007)           /*!< MODE[2:0] bits (ģʽѡ) */

#define  UART_WP_8D			                   ((u32)0x00000001)
#define  UART_WP_7DP											 ((u32)0x00000003)
#define  UART_WP_9D			                   ((u32)0x00000004)
#define  UART_WP_8DP		                   ((u32)0x00000007)

#define  UART_CR_STOP                      ((u32)0x00000018)           /*!< STOP[1:0] bits (ֹͣλѡ) */
#define  UART_STOP_05b		                 ((u32)0x00000000)
#define  UART_STOP_1b		                   ((u32)0x00000008)
#define  UART_STOP_15b		                 ((u32)0x00000010)
#define  UART_STOP_2b		                   ((u32)0x00000018)

#define  UART_CR_PS                        ((u32)0x00000020)           /*!< żУ鷽ʽ */
#define  UART_CR_LPB                       ((u32)0x00000040)           /*!< ģʽ */
#define  UART_CR_EN                        ((u32)0x00000080)           /*!< ʷʹ */
#define  UART_CR_RE                        ((u32)0x00000100)           /*!< ݽʹ */
#define  UART_CR_RXP                       ((u32)0x00010000)           /*!< ݽռԿ */
#define  UART_CR_TXP                       ((u32)0x00020000)           /*!< ݷͼԿ */
#define  UART_CR_OWE                       ((u32)0x00100000)           /*!< OneWireģʽʹ */
#define  UART_CR_OWD                       ((u32)0x00200000)           /*!< OneWireģʽշ */

/******************  Bit definition for UART_BRR register  *******************/
#define  UART_BRR_BR                       ((u32)0x0000FFFF)               /*!< BRR[15:0] bits () */

/******************  Bit definition for UART_IE register  *******************/
#define  UART_IE_RXNEI                   ((u32)0x00000001)        /*!< ջзǿжλ */
#define  UART_IE_RXHFI                   ((u32)0x00000002)        /*!< ջажλ */
#define  UART_IE_RXFI                    ((u32)0x00000004)        /*!< ջȫжλ */
#define  UART_IE_RXCOTI                  ((u32)0x00000008)        /*!< ջճʱжλ */
#define  UART_IE_IDLEI                   ((u32)0x00000010)        /*!< гʱжλ */
#define  UART_IE_PEI                     ((u32)0x00000020)        /*!< żУжλ */      
#define  UART_IE_FEI                     ((u32)0x00000040)        /*!< ֡жλ */
#define  UART_IE_OVRI                    ((u32)0x00000080)        /*!< ջжλ */    
#define  UART_IE_TXEI                    ((u32)0x00000100)        /*!< ͻȫжλ */         
#define  UART_IE_TXHEI                   ((u32)0x00000200)        /*!< ͻажλ */       
#define  UART_IE_TXFI                    ((u32)0x00000400)        /*!< ͻȫжλ */   
#define  UART_IE_TXOI                    ((u32)0x00000800)        /*!< ȫжλ */  


///******************  Bit definition for UART_SR register  *******************/
#define  UART_BRR_SR                       ((u32)0x00030000)               /*!<  */
#define  UART_BRR_SRX16                    ((u32)0x00000000)               /*!<  */
#define  UART_BRR_SRX8                     ((u32)0x00010000)               /*!<  */
#define  UART_BRR_SRX4                     ((u32)0x00020000)               /*!<  */

/******************  Bit definition for UART_SR register  *******************/
#define  UART_SR_RXNE                     ((u32)0x00000001)        /*!< ջзǿжϱʶλ */
#define  UART_SR_RXHF                     ((u32)0x00000002)        /*!< ջажϱʶλ */
#define  UART_SR_RXF                      ((u32)0x00000004)        /*!< ջȫжϱʶλ */
#define  UART_SR_RXCOT                    ((u32)0x00000008)        /*!< ջճʱжϱʶλ */
#define  UART_SR_IDLE                     ((u32)0x00000010)        /*!< гʱжϱʶλ */
#define  UART_SR_PE                       ((u32)0x00000020)        /*!< żУжϱʶλ */      
#define  UART_SR_FE                       ((u32)0x00000040)        /*!< ֡жϱʶλ */
#define  UART_SR_OVR                      ((u32)0x00000080)        /*!< ջжϱʶλ */    
#define  UART_SR_TXE                      ((u32)0x00000100)        /*!< ͻȫжϱʶλ */         
#define  UART_SR_TXHE                     ((u32)0x00000200)        /*!< ͻажϱʶλ */       
#define  UART_SR_TXF                      ((u32)0x00000400)        /*!< ͻȫжϱʶλ */   
#define  UART_SR_TXO                      ((u32)0x00000800)        /*!< ȫжϱʶλ */  

/******************  Bit definition for UART_TO_TO register  *******************/
#define  UART_TO_TO                        ((uint8_t)0xFF)               /*!< TO[8:0] bits (ճʱʱĴλΪ) */

/******************  Bit definition for UART_TXFR register  *******************/
#define  UART_TXFR_TXFR                    ((u32)0xFFFFFFFF)        /*!< TXFR[31:0] bits (Ͷиλ) */

/******************  Bit definition for UART_RXFR register  *******************/
#define  UART_RXFR_RXFR                    ((u32)0xFFFFFFFF)        /*!< RXFR[31:0] bits (նиλ) */ 


/******************  Bit definition for UART_IRR register  *******************/
#define  UART_IRC_IRE                       ((u32)0x00000001)        /*!<⹦ʹܿ */
#define  UART_IRC_IRPN                      ((u32)0x00000002)        /*!<ⷢͼԿ */
#define  UART_IRC_IRBD                      ((u32)0x00000030)        /*!<SPD[1:0]ѡ */

/******************  Bit definition for UART_IRPWMC register  *******************/
#define  UART_IRDC_DUTY                ((u32)0x00000FFF)        /*!< PWMC[11:0] bits (ռձȿ) */

/******************************************************************************/
/*                                                                            */
/*                      Analog to Digital Converter (ADC)                     */
/*                                                                            */
/******************************************************************************/
/********************  Bits definition for ADC_CR register  ******************/
/** @defgroup ADC_channels **/
#define ADC_CR_CHS                				((u32)0x0000001F)
#define ADC_CR_EN                         ((u32)0x00000020)       /*!< ADCʹܿ            */

#define ADC_CR_SOC                        ((u32)0x00000080)       /*!< ADCת        */

#define ADC_CLK_DIV		0x00000300   /*!<  Synchronous clock mode divided bit */
#define ADC_CLK_DIV2	0x00000000   /*!<  Synchronous clock mode divided by 2 */
#define ADC_CLK_DIV4	0x00000100   /*!<  Synchronous clock mode divided by 4 */
#define ADC_CLK_DIV8	0x00000200   /*!<  Synchronous clock mode divided by 8 */
#define ADC_CLK_DIV16	0x00000300   /*!<  Synchronous clock mode divided by 16 */

#define ADC_CR_MODE                       ((u32)0x00001800)       /*!< ADCתģʽ        */
			
/** @defgroup ADC_data_align **/
#define ADC_CR_ALIGN                      ((u32)0x00002000)

/** @defgroup  ADC_BGS **/
#define ADC_CR_BGS	    	((u32)0x00004000)

/** @defgroup ADC_external_trigger_sources_for_channels_conversion **/
#define ADC_CR_TIMS		((u32)0x00030000)/* TIM */
#define ADC_CR_TIMS0	((u32)0x00000000)/* TIM0 */
#define ADC_CR_TIMS1	((u32)0x00010000)/* TIM1 */
#define ADC_CR_TIMS2	((u32)0x00020000)/* TIM2 */
    
/** @defgroup  ADC_CR_ADVRPS_Set **/
#define ADC_CR_ADVRPS	        ((u32)0x00700000)
                     
/** @defgroup ADC_CR_ADVRNS_Set **/
#define ADC_CR_ADVRNS				  ((u32)0x01000000)

/********************  Bits definition for ADC_SR register  ******************/
#define ADC_SR_EOC                          ((u32)0x00000001)       /*!< ADCתɱ־λ */
#define ADC_SR_RDY                          ((u32)0x00000002)       /*!< ADCʹܾ־λ*/
/********************  Bit definition for ADC_DR register  ********************/
#define  ADC_DR                             ((u32)0x0000FFFF)        /*!< Regular data */
/********************  Bit definition for ADC_SAMPLE register  ********************/
#define  ADC_SAMPLE                         ((u32)0x000000FF)        /*!< ʱĴλ */




/** RTC_CR **/
#define  RTC_CR_EN		((u32)0x00000001)       /*!<RTCʹܿλ        */
#define  RTC_CR_TF		((u32)0x00000002)       /*!<RTCʱʽλ        */
#define  RTC_CR_CLKS	 ((u32)0x00000004)       /*!<RTCʱѡλ */
#define  RTC_CR_TBOE	((u32)0x00000008)       /*!<RTCʱźʹܿλ */
#define  RTC_CR_TME	((u32)0x00000010)       /*!<RTCʹܿλ        */

/** RTC_SR1 **/
#define  RTC_SR1_UL	        ((u32)0x00000001)       /*!<RTC־λ */
#define  RTC_SR1_UNLOCK	    ((u16)0x0000)  /*!< Registers UnLock Synchronized flag */
#define  RTC_SR1_LOCK    		((u16)0x0001)  /*!< Registers Lock Synchronized flag */
#define  RTC_SR1_BUSY   		((u16)0x0002)  /*!< Registers Synchronized flag */

/** RTC_LOCK **/
#define RTC_LOCK_LOCK  ((u32)0x00000001)
#define RTC_LOCK_ULSC	 ((u32)0x00000002)
#define RTC_LOCK_LSC	 ((u32)0x00000004)
#define RTC_LOCK_KEYCODE  0x1ACCE551  //RTCԿ
/** RTC_CSEC **/
#define RTC_CSEC_DIGS  ((u32)0x0000000F)
#define RTC_CSEC_TENS  ((u32)0x00000070)
/** RTC_CMIN **/
#define RTC_CMIN_DIGS  ((u32)0x0000000F)
#define RTC_CMIN_TENS  ((u32)0x00000070)
/** RTC_CHOUR **/
#define RTC_CHOUR_DIGS  ((u32)0x0000000F)
#define RTC_CHOUR_TENS  ((u32)0x00000070)
#define RTC_CHOUR_PM		((u32)0x00000100)
/** RTC_CDAY **/
#define RTC_CDAY_DIGS  ((u32)0x0000000F)
#define RTC_CDAY_TENS  ((u32)0x00000070)
/** RTC_CWEEK **/
#define RTC_CWEEK_DIGS  ((u32)0x0000000F)
#define RTC_CWEEK_TENS  ((u32)0x00000070)
/** RTC_CMON **/
#define RTC_CMON_DIGS  ((u32)0x0000000F)
#define RTC_CMON_TENS  ((u32)0x00000070)
/** RTC_CYEAR **/
#define RTC_CYEAR_DIGS  ((u32)0x0000000F)
#define RTC_CYEAR_TENS  ((u32)0x00000070)

/** RTC_IE **/
#define RTC_IE_CSECE		((u16)0x0001)  /*!< Second interrupt */
#define RTC_IE_CMINE		((u16)0x0002)  /*!< Minutes interrupt */
#define RTC_IE_CHOURE		((u16)0x0004)  /*!< Hour interrupt */
#define RTC_IE_CDAYE		((u16)0x0008)  /*!< DAY interrupt */
#define RTC_IE_CMONE		((u16)0x0010)  /*!< Month interrupt */
#define RTC_IE_ALME     ((u16)0x0020)  /*!< Alarm interrupt */
/** RTC_SR2 **/
#define RTC_SR2_CSEC		((u16)0x0001)  /*!< Second FLAG */
#define RTC_SR2_CMIN		((u16)0x0002)  /*!< Minutes FLAG */
#define RTC_SR2_CHOUR		((u16)0x0004)  /*!< Hour FLAG */
#define RTC_SR2_DAY		  ((u16)0x0008)  /*!< DAY FLAG */
#define RTC_SR2_MON		  ((u16)0x0010)  /*!< Month FLAG */
#define RTC_SR2_ALM     ((u16)0x0020)  /*!< Alarm FLAG */

/** RTC_ASEC **/
#define RTC_ASEC_DIGS  ((u32)0x0000000F)
#define RTC_ASEC_TENS  ((u32)0x00000070)
/** RTC_AMIN **/
#define RTC_AMIN_DIGS  ((u32)0x0000000F)
#define RTC_AMIN_TENS  ((u32)0x00000070)
/** RTC_AHOUR **/
#define RTC_AHOUR_DIGS  ((u32)0x0000000F)
#define RTC_AHOUR_TENS  ((u32)0x00000070)


/******************************************************************************/
/*                                                                            */
/*                   Inter-integrated Circuit Interface (I2C)                 */
/*                                                                            */
/******************************************************************************/
/*******************  Bit definition for I2C_CR register  *******************/
#define  I2C_CR_ACK                         ((u32)0x00000004)        /* ACK generation (slave mode) */
#define  I2C_ACK_Enable		                	I2C_CR_ACK
#define  I2C_ACK_Disable			              ((u32)0x00000000)
#define  I2C_CR_SI                          ((u32)0x00000008)        /* Interrupt status */
#define  I2C_CR_STOP                        ((u32)0x00000010)        /* STOP generation (master mode) */
#define  I2C_CR_STAR                        ((u32)0x00000020)        /* START generation */
#define  I2C_CR_EN                          ((u32)0x00000040)        /* Peripheral enable */
#define  I2C_CR_HCT                         ((u32)0x0000F000)        /* CLK filtering delay*/
#define  I2C_CR_BR                          ((u32)0x03FF0000)        /* CLK DIV*/
/*******************  Bit definition for I2C_SR register  *******************/
#define I2C_SR_SR                          ((u32)0x000000F8)      
/*******************  Bit definition for I2C_DR register  *******************/
#define  I2C_DR_DR                          ((u32)0x000000FF)        /* Enable Broadcast addressing*/    
/*******************  Bit definition for I2C_OAR register  *******************/
#define  I2C_OAR_BC				((u32)0x00000001)        /* Enable Broadcast addressing  */    
#define  I2C_BC_Enable			I2C_OAR_BC
#define  I2C_BC_Disable			((u32)0x00000000)
#define  I2C_OAR_ADDR                       ((u32)0x000000FE)        /* Enable Broadcast addressing  */ 
/*******************  Bit definition for I2C_CCR register  *******************/
#define  I2C_CCR_MASK                       ((u32)0x000000FF)        /*  */
#define  I2C_CCR_ACK                        ((u32)0x00000004)        /* ACK generation (slave mode) */
#define  I2C_CCR_SI                         ((u32)0x00000008)        /* Interrupt status */
#define  I2C_CCR_STOP                       ((u32)0x00000010)        /* STOP generation (master mode) */
#define  I2C_CCR_STAR                       ((u32)0x00000020)        /* START generation */
#define  I2C_CCR_EN                         ((u32)0x00000040)        /* Peripheral enable */
#define  I2C_CCR_HCT                        ((u32)0x0000F000)        /* CLK filtering delay*/
#define  I2C_CCR_BR                         ((u32)0x03FF0000)        /* CLK DIV*/

/******************************************************************************/
/*                                                                            */
/*                        Serial Peripheral Interface (SPI)                   */
/*                                                                            */
/******************************************************************************/

/*******************  Bit definition for SPI_CR1 register  ********************/
#define  SPI_CR1_DFF                         ((u32)0x0000000F)         /* SPI_data_size */
#define  SPI_CR1_CPOL		                     ((u32)0x00000040)         /* Clock Polarity */
#define  SPI_CR1_CPHA		                     ((u32)0x00000080)         /* Clock Phase */
#define  SPI_CR1_SCR                         ((u32)0x0000FF00)         /* Post-division factor */
/*******************  Bit definition for SPI_CR2 register  ********************/
#define  SPI_CR2_LBM				                 ((u32)0x00000001)         /* Loopback Mode */
#define  SPI_CR2_EN				                 ((u32)0x00000002)         /* SPI ENABLE*/
#define  SPI_CR2_MSM			                   ((u32)0x00000004)         /* Master-slave selection */
#define  SPI_CR2_SOD                         ((u32)0x00000008)       /* ӻ   */
/********************  Bit definition for SPI_DR register  ********************/
#define  SPI_DR_DR                           ((u16)0xFFFF)            /* Data Register */
/********************  Bit definition for SPI_SR1 register  ********************/
#define  SPI_SR1_TXE                            ((u32)0x00000001)         /* Transmission FIFO is empty */
#define  SPI_SR1_TNF                            ((u32)0x00000002)         /* Transmission FIFO is not empty */
#define  SPI_SR1_RXNE                           ((u32)0x00000004)         /* Receiver FIFO is not empty */
#define  SPI_SR1_RXF                            ((u32)0x00000008)         /* Receiver FIFO is Full */
#define  SPI_SR1_BSY                            ((u32)0x00000010)         /* Transmission module is busy */	
#define  SPI_SR1_RXFS                           ((u32)0x00000F00)       /* RXFIFOݸ */
#define  SPI_SR1_TXFS                           ((u32)0x0000F000)       /* TXFIFOݸʽ */
/********************  Bit definition for SPI_BR register  ********************/
#define  SPI_BR_BR                          ((u32)0x000000FF)         /* Prescaler factor */
/********************  Bit definition for SPI_IE register  ********************/
#define  SPI_IE_OVRE                        ((u32)0x00000001)         /* Receiver FIFO overflow */
#define  SPI_IE_OTE                         ((u32)0x00000002)         /* Receiver FIFO Non-empty timeout */
#define  SPI_IE_RXHE                        ((u32)0x00000004)         /* Receiver FIFO Half-full */
#define  SPI_IE_TXHE                        ((u32)0x00000008)         /* Transmission FIFO Half-full */
/********************  Bit definition for SPI_SR2 register  ********************/
#define  SPI_SR2_VOR                        ((u32)0x00000001)         /* Receiver FIFO overflow */
#define  SPI_SR2_OT                         ((u32)0x00000002)         /* Receiver FIFO Non-empty timeout */
#define  SPI_SR2_RXH                        ((u32)0x00000004)         /* Receiver FIFO Half-full */
#define  SPI_SR2_TXH                        ((u32)0x00000008)         /* Transmission FIFO Half-full */
/********************  Bit definition for SPI_MIS register  ********************/
#define  SPI_MIS_OV								((u32)0x00000001)       /* FIFOжϱ־  */
#define  SPI_MIS_TO								((u32)0x00000002)       /* FIFOǿղʱжϱ־  */
#define  SPI_MIS_RX								((u32)0x00000004)       /* FIFOݰжϱ־  */
#define  SPI_MIS_TX								((u32)0x00000008)       /* FIFOݰжϱ־  */
/********************  Bit definition for SPI_IFC register  ********************/
#define  SPI_IFC_OVR                       ((u32)0x00000001)         /* Receiver FIFO overflow */
#define  SPI_IFC_OT                         ((u32)0x00000002)         /* Receiver FIFO Non-empty timeout */
/********************  Bit definition for SPI_CSS register  ********************/
#define  SPI_CSS_CSS				((u32)0x00000004)         /* CS is controlled by software  */
#define  SPI_CSS_Soft				SPI_CSS_CSS
#define  SPI_CSS_Hard			  ((u16)0x0000)
#define  SPI_CSS_SWCS			  ((u16)0x0008)         /* CS Set Bit by software  */




/******************************************************************************/
/*                                                                            */
/*                       Comparators (CMP)                  			*/
/*                                                                            */
/******************************************************************************/

/*******************  Bit definition for OPA_CR register  ********************/
#define CMP_CR1_EN                  ((u32)0x00000001)          /*!< Comparator /Op Amp Enable */
#define CMP_CR1_CRS                 ((u32)0x00000002)          /*!< Comparator Output when Positive input is greater than negative input */

#define CMP_CR1_DFC                 ((u32)0x00000070)          /*!< Comparator Digital filter sampling rate Set */
#define CMP_CR1_CPMS                ((u32)0x00000080)          /*!< Comparator High speed mode */
#define CMP_CR1_OPC                 ((u32)0x00000100)          /*!< Comparator Output polarity selection */

#define CMP_CR1_CPS                 ((u32)0x0000000C)          /*!< Comparator Positive input source Select */

#define OPA_CR2_OPAEN	              ((u32)0x00000001)          /*!< Enable Operational amplifier mode */
#define CMP_CR2_TME	                ((u32)0x00000002)          /*!< OPA working MODE selection*/

#define CMP_CR2_TRIM	              ((u32)0x000001F0)          /*!< OPA offset calibration value*/

#define CMP_CR2_KEY			((u32)0xFFFF0000)

/********************  Bit definition for OPA_IE register  ********************/
#define  CMP_IE_COF                   ((u32)0x00000001)         /*!< Comparator output falling edge trigger interrupt enable */
#define  CMP_IE_COR                   ((u32)0x00000002)         /*!< Comparator output rising edge trigger interrupt enable */
#define  CMP_IE_COFW                  ((u32)0x00000004)         /*!< Comparator output falling edge trigger interrupt enable */
#define  CMP_IE_CORW                  ((u32)0x00000008)         /*!< Comparator output rising edge trigger interrupt enable */

/********************  Bit definition for OPA_EIS register  ********************/
#define  CMP_SR_COF                   ((u32)0x00000001)         /*!< Comparator output falling edge trigger interrupt enable */
#define  CMP_SR_COR                   ((u32)0x00000002)         /*!< Comparator output rising edge trigger interrupt enable */
#define  CMP_SR_COFW                  ((u32)0x00000004)         /*!< Comparator output falling edge trigger interrupt enable */
#define  CMP_SR_CORW                  ((u32)0x00000008)         /*!< Comparator output rising edge trigger interrupt enable */


/******************************************************************************/
/*                                                                            */
/*                       opamp (OPA)                  			*/
/*                                                                            */
/******************************************************************************/
#define OPA_CR1_EN			((u32)0x00000001)
#define OPA_CR1_OPS		((u32)0x0000000C)
#define OPA_CR1_OPMS		((u32)0x00000080)
#define OPA_CR2_TME		((u32)0x00000002)
#define OPA_CR2_TRIM		((u32)0x000001F0)
#define OPA_CR2_KEY		((u32)0xFFFF0000)

#define OPA_CR2_AFO1E		((u32)0x00001000)
#define OPA_CR2_AFO2E		((u32)0x00002000)
#define OPA_CR2_AFO3E		((u32)0x00004000)
#define OPA_CR2_AFGE		((u32)0x00008000)



/******************************************************************************/
/*                                                                            */
/*                      TIM Registers                                     */
/*                                                                            */
/******************************************************************************/

/*******************  Bit definition for TIM_ISR register  *******************/  
#define  TIM_SR_ARF                        ((u32)0x00000001)       /*!<ʱMR0ֵƥжϱ־λ       */

/*******************  Bit definition for TIM_TCR register  *******************/  
#define  TIM_CR1_EN                       ((u32)0x00000001)       /*!<ʱʹܿλ        */
#define  TIM_CR1_UG                        ((u32)0x00000002)       /*!<ʱƥֵ        */

/*******************  Bit definition for TIM_PSC register  *******************/  
#define  TIM_PSC                            ((uint8_t)0xFF)               /*!<PR[7:0]ʱԤƵϵ   */

/*******************  Bit definition for TIM_CNT register  *******************/  
#define  TIM_CNT                            ((u16)0xFFFF)            /*!<PC[15:0]ʱǰֵ   */

/*******************  Bit definition for TIM_MCR register  *******************/  
#define  TIM_CR2_ARI                       ((u32)0x00000001)        /*!<TIM_CNTMR0ֵƥʱжϿλ          */
#define  TIM_CR2_RSTC                      ((u32)0x00000002)        /*!<TIM_CNTMR0ֵƥʱλλ          */
#define  TIM_CR2_OPM                       ((u32)0x00000004)        /*!<TIM_CNTMR0ֵƥʱֹͣλ        */
#define  TIM_CR2_DIR                       ((u32)0x00000008)       /*!<TIM_CNTλ                       */


/*******************  Bit definition for PWM_ARR register  *******************/  
#define  TIM_ARR                           ((u16)0xFFFF)            /*!<MR0[15:0]ʱMR0ƥֵ   */


/******************************************************************************/
/*                                                                            */
/*                      TIM0&TIM1  Registers                                     */
/*                                                                            */
/******************************************************************************/

/*******************  Bit definition for PWM_SR register  *******************/  
#define  PWM_SR_ARF                      ((u32)0x00000001)       /*!<ʱƥ0־λ       */
#define  PWM_SR_OC1F                     ((u32)0x00000002)       /*!<ʱƥ1־λ       */
#define  PWM_SR_OC2F                     ((u32)0x00000004)       /*!<ʱƥ2־λ       */
#define  PWM_SR_OC3F                     ((u32)0x00000008)       /*!<ʱƥ3־λ       */
#define  PWM_SR_OC4F                     ((u32)0x00000010)       /*!<ʱƥ4־λ       */
#define  PWM_SR_IC1R                     ((u32)0x00000020)       /*!<ʱ1ر־λ */
#define  PWM_SR_IC1F                     ((u32)0x00000040)       /*!<ʱƥ1½ر־λ */
#define  PWM_SR_IC2R                     ((u32)0x00000080)       /*!<ʱƥ2ر־λ */
#define  PWM_SR_IC2F                     ((u32)0x00000100)       /*!<ʱƥ2½ر־λ */
#define  PWM_SR_IC3R                     ((u32)0x00000200)       /*!<ʱƥ3ر־λ */
#define  PWM_SR_IC3F                     ((u32)0x00000400)       /*!<ʱƥ3½ر־λ */
#define  PWM_SR_IC4R                     ((u32)0x00000800)       /*!<ʱƥ4ر־λ */
#define  PWM_SR_IC4F                     ((u32)0x00001000)       /*!<ʱƥ4½ر־λ */
#define  PWM_SR_BIF                      ((u32)0x00002000)       /*!<ʱɲ־λ    */

/*******************  Bit definition for PWM_CR1 register  *******************/  
#define  PWM_CR1_EN                    ((u32)0x00000001)       /*!<ʱʹܿλ          */
#define  PWM_CR1_UG                    	((u32)0x00000002)       /*!<ʱƥֵ          */
#define  PWM_CR1_CLKS                   ((u32)0x00000004)       /*!<ʱʱѡ        */
#define  PWM_CR1_CLKS_PCLK							((u32)0x00000000)
#define  PWM_CR1_CLKS_SYS								((u32)0x00000004)
#define  PWM_CR1_BKIS                   ((u32)0x00000070)       /*!<ʱɲԴѡλ*/


/*******************  Bit definition for PWM_ITARR register  *******************/  
#define  PWM_ITARR                       ((uint8_t)0xF)               /*!<INT_RPT[3:0]ʱжۼƴλ   */

/*******************  Bit definition for PWM_ITCNT register  *******************/  
#define  PWM_ITCNT                       ((uint8_t)0xF)               /*!<INT_RPTC[3:0]ʱжۼƴǰֵ   */

/*******************  Bit definition for PWM_PSC register  *******************/  
#define  PWM_PSC                         ((uint8_t)0xFF)               /*!<PR[7:0]ʱԤƵϵ   */

/*******************  Bit definition for PWM_CNT register  *******************/  
#define  PWM_CNT                         ((u16)0xFFFF)            /*!<PC[15:0]ʱǰֵ   */

/*******************  Bit definition for PWM_CR2 register  *******************/  
#define  PWM_CR2_ARI                      ((u32)0x00000001)       /*!<PMW_TCPWM_ARRƥʱжϿλ        */
#define  PWM_CR2_OC1I                     ((u32)0x00000002)       /*!<PMW_TCPWM_OCR1ƥʱжϿλ        */
#define  PWM_CR2_OC2I                     ((u32)0x00000004)       /*!<PMW_TCPWM_OCR2ƥʱжϿλ        */
#define  PWM_CR2_OC3I                     ((u32)0x00000008)       /*!<PMW_TCPWM_OCR3ƥʱжϿλ        */
#define  PWM_CR2_OC4I                     ((u32)0x00000010)       /*!<PMW_TCPWM_OCR4ƥʱжϿλ        */
#define  PWM_CR2_OPM                      ((u32)0x00000020)       /*!<PMW_TCPWM_ARRƥʱʱֹͣλ      */
#define  PWM_CR2_DIR                      ((u32)0x00000040)       /*!<PWM_CNTλ                       */
#define  PWM_CR2_CMS                      ((u32)0x00000080)       /*!<PWM_CNTλ                   */

/*******************  Bit definition for PWM_ARR register  *******************/  
#define  PWM_ARR                          ((u16)0xFFFF)            /*!<MR0[15:0]ʱMR0ƥֵ   */

/*******************  Bit definition for PWM_OCR1 register  *******************/  
#define  PWM_OCR1                         ((u16)0xFFFF)            /*!<MR1[15:0]ʱMR1ƥֵ   */

/*******************  Bit definition for PWM_OCR2 register  *******************/  
#define  PWM_OCR2                         ((u16)0xFFFF)            /*!<MR2[15:0]ʱMR2ƥֵ   */

/*******************  Bit definition for PWM_OCR3 register  *******************/  
#define  PWM_OCR3                         ((u16)0xFFFF)            /*!<MR3[15:0]ʱMR3ƥֵ   */

/*******************  Bit definition for PWM_OCR4 register  *******************/  
#define  PWM_OCR4                         ((u16)0xFFFF)            /*!<MR4[15:0]ʱMR4ƥֵ   */

/*******************  Bit definition for PWM_CAPR register  *******************/  
#define  PWM_CAPR_IC1R                    ((u32)0x00000001)       /*!<ͨ1ز׽ʹܿ          */
#define  PWM_CAPR_IC1F                    ((u32)0x00000002)       /*!<ͨ1½ز׽ʹܿ          */
#define  PWM_CAPR_IC1RC                   ((u32)0x00000004)       /*!<ͨ1ز׽λʹܿ    */
#define  PWM_CAPR_IC1I                    ((u32)0x00000008)       /*!<ͨ1ز׽жʹܿ          */
#define  PWM_CAPR_IC2R                    ((u32)0x00000010)       /*!<ͨ2ز׽ʹܿ          */
#define  PWM_CAPR_IC2F                    ((u32)0x00000020)       /*!<ͨ2½ز׽ʹܿ          */
#define  PWM_CAPR_IC2RC                   ((u32)0x00000040)       /*!<ͨ2ز׽λʹܿ    */
#define  PWM_CAPR_IC2I                    ((u32)0x00000080)       /*!<ͨ2ز׽жʹܿ          */
#define  PWM_CAPR_IC3R                    ((u32)0x00000100)       /*!<ͨ3ز׽ʹܿ          */
#define  PWM_CAPR_IC3F                    ((u32)0x00000200)       /*!<ͨ3½ز׽ʹܿ          */
#define  PWM_CAPR_IC3RC                   ((u32)0x00000400)       /*!<ͨ3ز׽λʹܿ    */
#define  PWM_CAPR_IC3I                    ((u32)0x00000800)       /*!<ͨ3ز׽жʹܿ          */
#define  PWM_CAPR_IC4R                    ((u32)0x00001000)       /*!<ͨ4ز׽ʹܿ          */
#define  PWM_CAPR_IC4F                    ((u32)0x00002000)       /*!<ͨ4½ز׽ʹܿ          */
#define  PWM_CAPR_IC4RC                   ((u32)0x00004000)       /*!<ͨ4ز׽λʹܿ    */
#define  PWM_CAPR_IC4I                    ((u32)0x00008000)       /*!<ͨ4ز׽жʹܿ          */

/*******************  Bit definition for PWM_CR1 register  *******************/  
#define  PWM_ICR1                       ((u32)0x0000FFFF)       /*!<CAP[15:0]׽ͨ1ر仯ֵ   */

/*******************  Bit definition for PWM_CR2 register  *******************/ 
#define  PWM_ICR2                       ((u32)0x0000FFFF)       /*!<CAP[15:0]׽ͨ2ر仯ֵ   */

/*******************  Bit definition for PWM_CR3 register  *******************/  
#define  PWM_ICR3                       ((u32)0x0000FFFF)       /*!<CAP[15:0]׽ͨ3ر仯ֵ   */

/*******************  Bit definition for PWM_CR4 register  *******************/  
#define  PWM_ICR4                       ((u32)0x0000FFFF)       /*!<CAP[15:0]׽ͨ4ر仯ֵ   */

/*******************  Bit definition for PWM_CMR register  *******************/  
#define  PWM_OCMR_OC1M                       ((u32)0x00000003)       /*!<MC1[2:0]  ͨ1Ƚģʽѡ    */
#define  PWM_OCMR_OC2M                       ((u32)0x00000030)       /*!<MC2[6:4]  ͨ2Ƚģʽѡ    */
#define  PWM_OCMR_OC3M                       ((u32)0x00000300)       /*!<MC3[10:8] ͨ3Ƚģʽѡ    */
#define  PWM_OCMR_OC4M                       ((u32)0x00003000)       /*!<MC4[14:12]ͨ4Ƚģʽѡ    */
#define  PWM_OCMR_OIS1              			   ((u32)0x00010000)       /*!<ͨ1ʼֵ                        */
#define  PWM_OCMR_OIS2                 			 ((u32)0x00020000)       /*!<ͨ2ʼֵ                        */
#define  PWM_OCMR_OIS3                 			 ((u32)0x00040000)       /*!<ͨ3ʼֵ                        */
#define  PWM_OCMR_OIS4                       ((u32)0x00080000)       /*!<ͨ4ʼֵ                        */
#define  PWM_OCMR_OIS1N           			     ((u32)0x00100000)       /*!<ͨ1ʼֵ                */
#define  PWM_OCMR_OIS2N             			   ((u32)0x00200000)       /*!<ͨ2ʼֵ                */
#define  PWM_OCMR_OIS3N             			   ((u32)0x00400000)       /*!<ͨ3ʼֵ                */
#define  PWM_OCMR_OIS4N             			   ((u32)0x00800000)       /*!<ͨ4ʼֵ                */
#define  PWM_OCMR_OC1NE             		     ((u32)0x01000000)       /*!<ͨ1ʹ                  */
#define  PWM_OCMR_OC2NE              		     ((u32)0x02000000)       /*!<ͨ2ʹ                  */
#define  PWM_OCMR_OC3NE               		   ((u32)0x04000000)       /*!<ͨ3ʹ                  */
#define  PWM_OCMR_OC4NE              		     ((u32)0x08000000)       /*!<ͨ4ʹ                  */
#define  PWM_OCMR_BKE                        ((u32)0x10000000)       /*!<ɲʹܿ                       */
#define  PWM_OCMR_BKP                        ((u32)0x20000000)       /*!<ɲЧƽ                   */
#define  PWM_OCMR_BKI                        ((u32)0x40000000)       /*!<ɲжʹܿ                   */

/*******************  Bit definition for PWM_DT register  *******************/  
#define  PWM_DT                              ((uint8_t)0xFF)              /*!<DT[7:0]ʱ   */
/******************************************************************************/
/*                                                                            */
/*                      CRC Registers                                     */
/*                                                                            */
/******************************************************************************/

/*******************  Bit definition for CRC_CR register  *******************/  
#define CRC_CR_EN                         ((u32)0x00000001)          /*!< CRC Enable */
#define CRC_CR_CRS                         ((u32)0x00000002)          /*!< CRC Initial */
#define CRC_CR_CIS                         ((u32)0x00000004)          /*!< CRC DataIn Width */
#define CRC_CIS_16b		                     ((u32)0x00000004)	       /* CRC DataIn Width 16bit*/
#define CRC_CIS_8b		                     ((u32)0x00000000)	       /* CRC DataIn Width 8bit*/
#define CRC_CR_CISN                        ((u32)0x00000008)          /*!< CRC DataIn Width */
#define CRC_CR_CBN                         ((u32)0x00000010)          /*!< CRC DataIn Width */
#define CRC_CR_COSN                        ((u32)0x00000020)          /*!< CRC DataIn Width */

/*******************  Bit definition for CRC_SEED register  *******************/  
#define CRC_SEED_MASK                      ((u32)0x0000FFFF)          /*!< CRC SEED */

/*******************  Bit definition for CRC_POLY register  *******************/  
#define CRC_POLY_MASK                      ((u32)0x0000FFFF)          /*!< CRC POLY */

/*******************  Bit definition for CRC_POLY register  *******************/  
#define CRC_DIN_MASK                       ((u32)0x0000FFFF)          /*!< CRC DATA INPUT */

/*******************  Bit definition for CRC_POLY register  *******************/  
#define CRC_DOUT_MASK                      ((u32)0x0000FFFF)          /*!< CRC DATA OUT */

/******************************************************************************/
/*                                                                            */
/*                        Independent WATCHDOG (WDG)                         */
/*                                                                            */
/******************************************************************************/
/*******************  Bit definition for WDG_RLR register  *******************/
#define  WDG_RLR_RL                         ((u32)0xFFFFFFFF)            /*!< Watchdog counter reload value */

/*******************  Bit definition for WDG_Count register  *******************/ 
#define  WDG_CNT_CNT                        ((u32)0xFFFFFFFF)            /*!< Watchdog count value          */

/*******************  Bit definition for WDG_CR register  *******************/  
#define  WDG_CR_EN                          ((u32)0x00000001)       /*!< Enable IWDG        */
#define  WDG_CR_RSTE                        ((u32)0x00000002)       /*!< RESET IWDG         */
#define  WDG_CR_DBGE                        ((u32)0x00000004)       /*!< DEBUG IWDG         */

#define  WDG_KR_KEY                         ((u32)0xFFFFFFFF)
/*******************  Bit definition for WDG_RIS register  *******************/  
#define  WDG_SR_HDF                         ((u32)0x00000001)               /*!< Watchdog counter reload value update */

/*******************  Bit definition for WDG_KR register  ********************/
#define  WDG_LOCK_KEY                       ((u32)0xFFFFFFFF)            /*!< Key value (write only, read 0000h) */
#define  WDG_LOCK_FLAG                      ((u32)0x00000001)            /*!< IWDG LOCK        */

/******************************************************************************/
/*                                                                            */
/*                        Independent BEEP (BEEP)                         */
/*                                                                            */
/******************************************************************************/
#define  BEEP_CR_EN                         ((u32)0x00000001)       /*!< Enable BEEP        */
#define  BEEP_CR_PRE                        ((u32)0x0000003E)       /*!<         */
#define  BEEP_CR_DIV                        ((u32)0x000000C0)       /*!<         */
#define  BEEP_HCR_PC2HS                     ((u32)0x00000001)
#define  BEEP_HCR_PD5HS                     ((u32)0x00000002)

/******************************************************************************/
/*                                                                            */
/*                        LCD                                                 */
/*                                                                            */
/******************************************************************************/
#define  LCD_CR_EN		((uint32_t)0x00000001)       /*!<LCDģʹܿλ        */
#define  LCD_CR_TYPE  ((u32)0x00000002)
#define  LCD_CR_DUTY  ((u32)0x0000000C)
#define  LCD_CR_WAVE  ((u32)0x00000010)
#define  LCD_CR_BLINK ((u32)0x00000020)
#define  LCD_CR_CLKS  ((u32)0x00000040)
#define  LCD_CR_DU	  ((uint32_t)0x00000080)       /*!<LCDݸʹλ        */
#define  LCD_CR_AON	  ((uint32_t)0x00000200)
#define  LCD_CR_AOFF	((uint32_t)0x00000400)
#define  LCD_CR_LCDIE ((u32)0x00000800)
#define  LCD_CR_PDM   ((u32)0x00003000)
#define  LCD_CR_CPE   ((u32)0x00004000)
#define  LCD_CR_RSEL  ((u32)0x00008000)

#define  LCD_GCR_EN	  ((u32)0x00000001)
#define  LCD_GCR_GDR  ((u32)0x0000000E)

#define  LCD_PSC      ((u32)0x0000001F)

#define  LCD_BTCR_BT  ((u32)0x000000FF)

#define  LCD_BON_ON   ((u32)0x000000FF)

#define  LCD_PCR_PE   ((u32)0xFFFFFFFF)

#define  LCD_PDCR_PDC ((u32)0xFFFFFFFF)

#define  LCD_SDPR_SDP ((u32)0x0000000F)

#define  LCD_PNR_PN	  ((u32)0x0000000F)

#define  LCD_PxLy_COMn   ((u32)0x000000FF)
/**
  * @}
  */


#ifdef USE_STDPERIPH_DRIVER
  #include "PT32x033x_conf.h"
#endif

  
#ifdef __cplusplus
}
#endif

#endif 

