  /******************************************************************************
  * @file   PT32x033x_adc.h
  * @author  ӦÿŶ
  * @version V1.4.0
  * @date    2023/10/27
  * @brief   This file contains all the functions prototypes for the ADC firmware library
  *          
  ******************************************************************************
  * @attention
  *
  *
  *****************************************************************************/

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef PT32x033x_ADC_H
#define PT32x033x_ADC_H

#ifdef __cplusplus
extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x033x.h"


/** @addtogroup ADC
  * @{
  */


/* Exported types ------------------------------------------------------------*/

/** @brief  ADC Init structure definition **/
typedef struct
{
	u32 ADC_Prescaler;
	u32 ADC_MODE;
	u32 ADC_TIMS;                                             
	u32 ADC_ALIGN;	
	u32 ADC_Channel;      
	u32 ADC_AnalogChannel;	
  u32 ADC_ReferencePositive;
} ADC_InitTypeDef;


#define IS_ADC_ALL_PERIPH(PERIPH)                  ((PERIPH) == ADC)

/** @defgroup ADC_MODE_SEL **/
#define ADC_MODE_Single			(ADC_CR_MODE&0x0000)
#define ADC_MODE_Continuous	(ADC_CR_MODE&0x1000)
#define ADC_MODE_TIM			(ADC_CR_MODE&0x0800)
#define IS_ADC_MODE_SEL(SEL)	(((SEL) == ADC_MODE_Single)   ||\
								((SEL) == ADC_MODE_Continuous)   ||\
								((SEL) == ADC_MODE_TIM))

/** @defgroup IS_ADC_PSC_SEL **/
#define IS_ADC_PSC_SEL(CLOCK) 	(((CLOCK) == ADC_CLK_DIV16)  ||\
								((CLOCK) == ADC_CLK_DIV2) ||\
								((CLOCK) == ADC_CLK_DIV4) ||\
								((CLOCK) == ADC_CLK_DIV8))

/** @defgroup IS_ADC_ALIGN_SEL **/
#define ADC_DataAlign_Right	(ADC_CR_ALIGN&0x0000)
#define ADC_DataAlign_Left	(ADC_CR_ALIGN)
#define IS_ADC_ALIGN_SEL(ALIGN) (((ALIGN) == ADC_DataAlign_Right) || \
								((ALIGN) == ADC_DataAlign_Left))

/** @defgroup IS_ADC_BGS_SEL **/
#define ADC_AnalogChannel_BG1v2 (ADC_CR_BGS&0x0000)
#define ADC_AnalogChannel_BG1v0 (ADC_CR_BGS&0x4000)
#define IS_ADC_BGS_SEL(ALIGN)	(((ALIGN) == ADC_AnalogChannel_BG1v2) || \
								((ALIGN) == ADC_AnalogChannel_BG1v0))


/** @defgroup IS_ADC_TIMS_SEL **/
#define ADC_TIMS_TIM0Trgo ADC_CR_TIMS0
#define ADC_TIMS_TIM1Trgo ADC_CR_TIMS1
#define ADC_TIMS_TIM2Trgo ADC_CR_TIMS2
#define IS_ADC_TIMS_SEL(CONV)	(((CONV) == ADC_TIMS_TIM0Trgo)   ||\
								((CONV) == ADC_TIMS_TIM1Trgo)   ||\
								((CONV) == ADC_TIMS_TIM2Trgo))

/** @defgroup IS_ADC_ADVRPS_SEL **/
#define ADC_ReferencePositive_VDDA (ADC_CR_ADVRPS&0x100000)
#define ADC_ReferencePositive_AVREF (ADC_CR_ADVRPS&0x200000)
#define ADC_ReferencePositive_BG2V0 (ADC_CR_ADVRPS&0x400000)
#define IS_ADC_ADVRPS_SEL(VREF) (((VREF) == ADC_ReferencePositive_VDDA) || \
								((VREF) == ADC_ReferencePositive_AVREF)|| \
								((VREF) == (ADC_ReferencePositive_BG2V0|ADC_ReferencePositive_AVREF)))

#define ADC_Channel_0  (ADC_CR_CHS&0x00)
#define ADC_Channel_1  (ADC_CR_CHS&0x01)
#define ADC_Channel_2  (ADC_CR_CHS&0x02)
#define ADC_Channel_3  (ADC_CR_CHS&0x03)
#define ADC_Channel_4  (ADC_CR_CHS&0x04)
#define ADC_Channel_5  (ADC_CR_CHS&0x05)
#define ADC_Channel_6  (ADC_CR_CHS&0x06)
#define ADC_Channel_7  (ADC_CR_CHS&0x07)
#define ADC_Channel_8  (ADC_CR_CHS&0x08)
#define ADC_Channel_9  (ADC_CR_CHS&0x09)
#define ADC_Channel_10 (ADC_CR_CHS&0x0A)
#define ADC_Channel_11 (ADC_CR_CHS&0x0B)
#define IS_ADC_CHS_SEL(CHANNEL)	(((CHANNEL) == ADC_Channel_0) ||\
									((CHANNEL) == ADC_Channel_1) ||\
									((CHANNEL) == ADC_Channel_2) ||\
									((CHANNEL) == ADC_Channel_3) ||\
									((CHANNEL) == ADC_Channel_4) ||\
									((CHANNEL) == ADC_Channel_5) ||\
									((CHANNEL) == ADC_Channel_6) ||\
									((CHANNEL) == ADC_Channel_7) ||\
									((CHANNEL) == ADC_Channel_8) ||\
									((CHANNEL) == ADC_Channel_9) ||\
									((CHANNEL) == ADC_Channel_10) ||\
									((CHANNEL) == ADC_Channel_11))

/** @defgroup IS_ADC_SMP_SEL **/                                    
#define IS_ADC_SMP_SEL(Value)	      (((Value) > 3) && ((Value) < 256))	

/** @defgroup IS_ADC_GET_FLAG **/  
#define ADC_FLAG_RDY              ADC_SR_RDY                     
#define ADC_FLAG_EOC              ADC_SR_EOC    
#define IS_ADC_GET_FLAG(FLAG) (((FLAG) == ADC_FLAG_RDY)   || ((FLAG) == ADC_FLAG_EOC))

/* Exported macro ------------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */
void ADC_DeInit(ADC_TypeDef* ADCx);
void ADC_Init(ADC_TypeDef* ADCx, ADC_InitTypeDef* ADC_InitStruct);
//void ADC_StructInit(ADC_InitTypeDef* ADC_InitStruct);
void ADC_Cmd(ADC_TypeDef* ADCx, FunctionalState NewState);
void ADC_SetSampleTime(ADC_TypeDef* ADCx, u32 sampletime);
void ADC_ChannelConfig(ADC_TypeDef* ADCx, u32 ADC_Channel);
u16 ADC_GetConversionValue(ADC_TypeDef* ADCx);
void ADC_ITConfig(ADC_TypeDef* ADCx, u32 ADC_IT, FunctionalState NewState);
FlagStatus ADC_GetFlagStatus(ADC_TypeDef* ADCx, u32 ADC_FLAG);
void ADC_ConversionConfig(ADC_TypeDef* ADCx,FunctionalState NewState);
/**
  * @}
  */
  
#ifdef __cplusplus
}
#endif

#endif


