/**
  ******************************************************************************
  * @file    PT32x033x_beep.h
  * @author  ӦÿŶ
  * @version V1.4.0
  * @date    2023/10/27
  * @brief   This file contains all the functions prototypes for the ADC firmware library
  *          
  ******************************************************************************
  * @attention
  *
  *
  *****************************************************************************/

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef PT32x033x_BEEP_H
#define PT32x033x_BEEP_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x033x.h"

/* Exported types ------------------------------------------------------------*/



/* Exported constants --------------------------------------------------------*/

/** @defgroup BEEP_Exported_Constants
  * @{
  */
/** 
  * @brief  BEEP Init structure definition
  */
  
typedef struct
{
	u32 BEEP_Prescaler;                        /*!<*/				
	u32 BEEP_Subdivide;                        /*!<*/				
}Beep_InitTypeDef;


#define BEEP_Subdivide_X2              ((u32)0x00000080)
#define BEEP_Subdivide_X4              ((u32)0x00000040)
#define BEEP_Subdivide_X8              ((u32)0x00000000)
#define BEEP_HighSink_PC2              ((u32)0x00000000)
#define BEEP_HighSink_PD5              ((u32)0x00000001)

#define IS_BEEP_SUBDIV(SUBDIV)     ((SUBDIV == BEEP_Subdivide_X2)   || \
                                    (SUBDIV == BEEP_Subdivide_X4)   || \
                                    (SUBDIV == BEEP_Subdivide_X8))

#define IS_BEEP_CPSR(CPSR)         (CPSR <= ((u32)0x0000001F))
#define IS_BEEP_PIN(pin)			((pin==BEEP_HighSink_PC2)||(pin==BEEP_HighSink_PD5))
/** @addtogroup BEEP_Exported_Functions
  * @{
  */
void Beep_Init(Beep_InitTypeDef* Beep_InitStruct);
void Beep_Cmd(FunctionalState NewState);
void Beep_PrescalerConfig(uint8_t Prescaler);
void Beep_SubDivConfig(uint8_t Subdivide);
void Beep_DeInit(void);
void Beep_HighSink(u32 pin,FunctionalState NewState);
/**
  * @}
  */
#ifdef __cplusplus
}
#endif

#endif 

