/******************************************************************************
  * @file    PT32x033x_cmp_opa.h
  * @author  ӦÿŶ
  * @version V1.4.0
  * @date    2020/10/19
  * @brief    This file contains all the functions prototypes for the CMP/CMP firmware library
  *
  ******************************************************************************
  * @attention
  *
  *
  *****************************************************************************/


/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef PT32x033x_CMP_CMP_H
#define PT32x033x_CMP_CMP_H

#ifdef __cplusplus
extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x033x.h"

/** @addtogroup Analog comparators and operational amplifiers
  * @{
  */

/* Exported types ------------------------------------------------------------*/

/** @brief  LED Init structure definition **/
typedef struct
{
	u32 CMP_PositiveInput;	/*!< */
	u32 CMP_DigitalFilter;	/*!<Digital filter sampling times.*/
	u32 CMP_PowerMode;
	u32 CMP_OutputPolarity;	/*!< */
} CMP_InitTypeDef;


/* Exported constants --------------------------------------------------------*/

/** @defgroup CMP_Exported_Constants **/
#define IS_CMP_ALL_PERIPH(PERIPH)			(((PERIPH) == CMP0) || ((PERIPH) == CMP1))
#define IS_CMP_INITDELAY_VALUE(VALUE)		((VALUE) <= 0x3FFF)
#define IS_CMP_DAC_VALUE(VALUE)			((VALUE) <= 0x1F)

#define CMP_TrimKey					((u32)0xACDE0000)

/** @defgroup CMP_FEFSEL **/
#define CMP_PositiveInput_CMPxP		(CMP_CR1_CPS&0x00)   /*!< */
#define CMP_PositiveInput_LDAC		(CMP_CR1_CPS&0x04)   /*!<*/
#define CMP_PositiveInput_DAC		(CMP_CR1_CPS&0x0C)
#define CMP_PositiveInput_BG1V0		(CMP_CR1_CPS&0x08)   /*!<*/
#define IS_CMP_PositiveInput(SOURCE)	(((SOURCE) == CMP_PositiveInput_CMPxP) ||\
									((SOURCE) == CMP_PositiveInput_LDAC) ||\
									((SOURCE) == CMP_PositiveInput_BG1V0)||\
									((SOURCE) == CMP_PositiveInput_DAC))
                                
/** @defgroup Digital filtering sampling times **/
#define CMP_DigitalFilter_NONE	(CMP_CR1_DFC&0x00)   /*!<*/
#define CMP_DigitalFilter_X2		(CMP_CR1_DFC&0x10)     /*!<*/
#define CMP_DigitalFilter_X4		(CMP_CR1_DFC&0x20)     /*!<*/
#define CMP_DigitalFilter_X8		(CMP_CR1_DFC&0x30)     /*!<*/
#define CMP_DigitalFilter_X16		(CMP_CR1_DFC&0x40)    /*!<*/
#define CMP_DigitalFilter_X32		(CMP_CR1_DFC&0x50)    /*!<*/
#define CMP_DigitalFilter_X64		(CMP_CR1_DFC&0x60)    /*!<*/
#define IS_CMP_DigitalFilter(TIMES)		(((TIMES) == CMP_DigitalFilter_NONE) ||\
									((TIMES) == CMP_DigitalFilter_X2) ||\
									((TIMES) == CMP_DigitalFilter_X4) ||\
									((TIMES) == CMP_DigitalFilter_X8) ||\
									((TIMES) == CMP_DigitalFilter_X16) ||\
									((TIMES) == CMP_DigitalFilter_X32) ||\
									((TIMES) == CMP_DigitalFilter_X64))


#define CMP_OutputPolarity_Positive ((u8)0x0)
#define CMP_OutputPolarity_Negetive	((u8)0x1)
#define IS_CMP_OutputPolarity(POLARITY) ((POLARITY==CMP_OutputPolarity_Positive)||\
										(POLARITY==CMP_OutputPolarity_Negetive))

#define CMP_PowerMode_HighSpeed ((u8)0x1)
#define CMP_PowerMode_LowPower	((u8)0x0)
#define IS_CMP_PowerMode(MODE) ((MODE==CMP_PowerMode_HighSpeed)||(MODE==CMP_PowerMode_LowPower))

/** @defgroup CMP_interrupts_definition **/
#define CMP_IT_Fall		CMP_IE_COF
#define CMP_IT_Rise		CMP_IE_COR
#define CMP_IT_FallWake	CMP_IE_COFW
#define CMP_IT_RiseWake	CMP_IE_CORW

#define IS_CMP_CONFIG_IT(IT) (((IT) != (u32)RESET) && (((IT) & 0xFFFFFFF0) == (u32)RESET))

#define IS_CMP_GET_IT(IT)    (((IT) == CMP_IT_Fall) ||\
							((IT) == CMP_IT_Rise) ||\
  							((IT) == CMP_IT_FallWake) ||\
							((IT) == CMP_IT_RiseWake))

#define IS_CMP_CLEAR_IT(IT)  (((IT) != (u32)RESET) && (((IT) & 0xFFFFFFF0) == (u32)RESET))

/** @defgroup CMP_flags_definition **/
#define CMP_FLAG_Fall			CMP_SR_COF
#define CMP_FLAG_Rise			CMP_SR_COR
#define CMP_FLAG_FallWake		CMP_SR_COFW
#define CMP_FLAG_RiseWake		CMP_SR_CORW
#define IS_CMP_GET_FLAG(FLAG) (((FLAG) == CMP_FLAG_Fall) ||\
                               ((FLAG) == CMP_FLAG_Rise) ||\
                               ((FLAG) == CMP_FLAG_FallWake) ||\
                               ((FLAG) == CMP_FLAG_RiseWake))

#define IS_CMP_CLEAR_FLAG(FLAG)  (((FLAG) != (u32)RESET) && (((FLAG) & 0xFFFFFFF0) == (u32)RESET))


/* Exported macro ------------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */
void CMP_DeInit(CMP_TypeDef* CMPx);
void CMP_Init(CMP_TypeDef* CMPx, CMP_InitTypeDef* CMP_InitStruct);
void CMP_StructInit(CMP_InitTypeDef* CMP_InitStruct);
void CMP_Cmd(CMP_TypeDef* CMPx, FunctionalState NewState);
void CMP_ITConfig(CMP_TypeDef* CMPx, u32 CMP_IT, FunctionalState NewState);
FlagStatus CMP_GetFlagStatus(CMP_TypeDef* CMPx, u32 CMP_FLAG);
void CMP_ClearFlag(CMP_TypeDef* CMPx, u32 CMP_FLAG);
ITStatus CMP_GetITStatus(CMP_TypeDef* CMPx, u32 CMP_IT);


/**
  * @}
  */
  
#ifdef __cplusplus
}
#endif

#endif

