/******************************************************************************
  * @file    PT32x033x_dac.h
  * @author  ӦÿŶ
  * @version V1.4.0
  * @date    2023/10/27
  * @brief    This file contains all the functions prototypes for the DAC firmware library.
  *          
  ******************************************************************************
  * @attention
  *
  *
  *****************************************************************************/

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef PT32x033x_DAC_H
#define PT32x033x_DAC_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x033x.h"

/** @addtogroup DAC
  * @{
  */ 
  
/* Exported types ------------------------------------------------------------*/
typedef struct
{
	u32 DAC_Prescaler;
	u32 DAC_RefVoltage;       
} DAC_InitTypeDef;


/* Exported constants --------------------------------------------------------*/
/** @defgroup DAC_Prescaler **/

#define DAC_Prescaler_EN		0x00000001 
#define DAC_Prescaler_40		0x00000000  
#define DAC_Prescaler_60		0x00000010  
#define DAC_Prescaler_80		0x00000020  
#define DAC_Prescaler_100	  0x00000030  
#define DAC_Prescaler_120	  0x00000040  
#define DAC_Prescaler_200	  0x00000050  
#define DAC_Prescaler_240	  0x00000060  
#define DAC_Prescaler_320	  0x00000070
#define IS_DAC_CLK_SEL(CLOCK) 	(((CLOCK) == DAC_Prescaler_40)  ||\
								((CLOCK) == DAC_Prescaler_60)||\
								((CLOCK) == DAC_Prescaler_80)||\
								((CLOCK) == DAC_Prescaler_100)||\
								((CLOCK) == DAC_Prescaler_120)||\
								((CLOCK) == DAC_Prescaler_200)||\
								((CLOCK) == DAC_Prescaler_240)||\
								((CLOCK) == DAC_Prescaler_320))

/** @defgroup DAC_RefVoltage **/
#define DAC_RefVoltage_BG2V0   	0x00000100   
#define DAC_RefVoltage_DVREF	  0x00000200



#define IS_DAC_PREF_SEL(CLOCK) 	(((CLOCK) == DAC_RefVoltage_BG2V0)||\
								((CLOCK) == DAC_RefVoltage_DVREF)||\
								((CLOCK) == (DAC_RefVoltage_BG2V0|DAC_RefVoltage_DVREF)))

/* Exported macro ------------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */
void DAC_Init(DAC_InitTypeDef* DAC_InitStruct);
void DAC_StructInit(DAC_InitTypeDef* DAC_InitStruct);
void DAC_SetData(u16 Value);
void DAC_Cmd(FunctionalState NewState);
void DAC_ITConfig(FunctionalState NewState);
FlagStatus DAC_GetFlagStatus(void);
void DAC_Wait_For_Transformat_OK(void);
void DAC_DeInit(void);

/**
  * @}
  */
  
#ifdef __cplusplus
}
#endif

#endif 


