 /******************************************************************************
  * @file    PT32x033x_gpio.h
  * @author  ӦÿŶ
  * @version V1.4.0
  * @date    2023/10/27
  * @brief    This file contains all the functions prototypes for the GPIO firmware library.
  *          
  ******************************************************************************
  * @attention
  *
  *
  *****************************************************************************/

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef PT32x033x_GPIO_H
#define PT32x033x_GPIO_H

#ifdef __cplusplus
extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x033x.h"


/** @addtogroup GPIO
  * @{
  */
  
/* Exported types ------------------------------------------------------------*/

/** @defgroup Configuration_Mode_enumeration **/
typedef enum
{
	GPIO_Mode_IN   = 0x00, 	/*!< GPIO Input Mode              */
	GPIO_Mode_OutPP,         	/*!< GPIO Output Mode             */
	GPIO_Mode_OutOD,
} GPIOMode_TypeDef;
#define IS_GPIO_MODE(MODE) (((MODE) == GPIO_Mode_IN)|| ((MODE) == GPIO_Mode_OutPP) || ((MODE) == GPIO_Mode_OutOD))


/** @defgroup Configuration_Pull-Up_Pull-Down_enumeration **/
typedef enum
{
	GPIO_PuPd_NOPULL = 0x00,
	GPIO_PuPd_UP     = 0x01,
	GPIO_PuPd_DOWN   = 0x02
} GPIOPuPd_TypeDef;
#define IS_GPIO_ALL_PERIPH(PERIPH) (((PERIPH) == GPIOA) || ((PERIPH) == GPIOB) || ((PERIPH) == GPIOC) || ((PERIPH) == GPIOD))
#define IS_GPIO_PUPD(PUPD) (((PUPD) == GPIO_PuPd_NOPULL) || ((PUPD) == GPIO_PuPd_UP) || ((PUPD) == GPIO_PuPd_DOWN))


/** @defgroup Bit_SET_and_Bit_RESET_enumeration **/
typedef enum
{
	Bit_RESET = 0,
	Bit_SET
} BitAction;
#define IS_GPIO_BIT_ACTION(ACTION) (((ACTION) == Bit_RESET) || ((ACTION) == Bit_SET))



/** @brief  GPIO Init structure definition **/
typedef struct
{
	u32 GPIO_Pin;              /*!< Specifies the GPIO pins to be configured.
                                       This parameter can be any value of @ref GPIO_pins_define */
	GPIOMode_TypeDef GPIO_Mode;     /*!< Specifies the operating mode for the selected pins.
                                       This parameter can be a value of @ref GPIOMode_TypeDef   */
	GPIOPuPd_TypeDef GPIO_PuPd;     /*!< Specifies the operating Pull-up/Pull down for the selected pins.
                                       This parameter can be a value of @ref GPIOPuPd_TypeDef   */
} GPIO_InitTypeDef;


/* Exported constants --------------------------------------------------------*/

#define GPIO_Pin_0                 ((u16)0x0001)  /*!< Pin 0 selected    */
#define GPIO_Pin_1                 ((u16)0x0002)  /*!< Pin 1 selected    */
#define GPIO_Pin_2                 ((u16)0x0004)  /*!< Pin 2 selected    */
#define GPIO_Pin_3                 ((u16)0x0008)  /*!< Pin 3 selected    */
#define GPIO_Pin_4                 ((u16)0x0010)  /*!< Pin 4 selected    */
#define GPIO_Pin_5                 ((u16)0x0020)  /*!< Pin 5 selected    */
#define GPIO_Pin_6                 ((u16)0x0040)  /*!< Pin 6 selected    */
#define GPIO_Pin_7                 ((u16)0x0080)  /*!< Pin 7 selected    */
#define GPIO_Pin_8                 ((u16)0x0100)  /*!< Pin 8 selected    */
#define GPIO_Pin_9                 ((u16)0x0200)  /*!< Pin 9 selected    */
#define GPIO_Pin_10                ((u16)0x0400)  /*!< Pin 10 selected   */
#define GPIO_Pin_11                ((u16)0x0800)  /*!< Pin 11 selected   */
#define GPIO_Pin_12                ((u16)0x1000)  /*!< Pin 12 selected   */
#define GPIO_Pin_13                ((u16)0x2000)  /*!< Pin 13 selected   */
#define GPIO_Pin_14                ((u16)0x4000)  /*!< Pin 14 selected   */
#define GPIO_Pin_15                ((u16)0x8000)  /*!< Pin 15 selected   */
#define GPIO_Pin_All               ((u16)0xFFFF)  /*!< All pins selected */
#define IS_GPIO_PIN_SEL(SEL) ((((SEL) & (u32)0xffff0000) == 0) && ((SEL) != (u32)0x0000))
#define IS_GET_GPIO_PIN(PIN) (((PIN) == GPIO_Pin_0) || \
                              ((PIN) == GPIO_Pin_1) || \
                              ((PIN) == GPIO_Pin_2) || \
                              ((PIN) == GPIO_Pin_3) || \
                              ((PIN) == GPIO_Pin_4) || \
                              ((PIN) == GPIO_Pin_5) || \
                              ((PIN) == GPIO_Pin_6) || \
                              ((PIN) == GPIO_Pin_7) || \
                              ((PIN) == GPIO_Pin_8) || \
                              ((PIN) == GPIO_Pin_9) || \
                              ((PIN) == GPIO_Pin_10) || \
                              ((PIN) == GPIO_Pin_11) || \
                              ((PIN) == GPIO_Pin_12) || \
                              ((PIN) == GPIO_Pin_13) || \
                              ((PIN) == GPIO_Pin_14) || \
                              ((PIN) == GPIO_Pin_15))

#define IS_GPIO_PIN_GET(SEL)	(((SEL) == GPIO_Pin_0) || \
								((SEL) == GPIO_Pin_1) || \
								((SEL) == GPIO_Pin_2) || \
								((SEL) == GPIO_Pin_3) || \
								((SEL) == GPIO_Pin_4) || \
								((SEL) == GPIO_Pin_5) || \
								((SEL) == GPIO_Pin_6) || \
								((SEL) == GPIO_Pin_7) || \
								((SEL) == GPIO_Pin_8) || \
								((SEL) == GPIO_Pin_9) || \
								((SEL) == GPIO_Pin_10) || \
								((SEL) == GPIO_Pin_11) || \
								((SEL) == GPIO_Pin_12) || \
								((SEL) == GPIO_Pin_13) || \
								((SEL) == GPIO_Pin_14) || \
								((SEL) == GPIO_Pin_15))
     
#define GPIO_FLAG_PR0                          GPIO_PR_PR0                    /*!< Port interrupt pending bit set, bit 0 */
#define GPIO_FLAG_PR1                          GPIO_PR_PR1                    /*!< Port interrupt pending bit set, bit 1 */
#define GPIO_FLAG_PR2                          GPIO_PR_PR2                    /*!< Port interrupt pending bit set, bit 2 */
#define GPIO_FLAG_PR3                          GPIO_PR_PR3                    /*!< Port interrupt pending bit set, bit 3 */
#define GPIO_FLAG_PR4                          GPIO_PR_PR4                    /*!< Port interrupt pending bit set, bit 4 */
#define GPIO_FLAG_PR5                          GPIO_PR_PR5                    /*!< Port interrupt pending bit set, bit 5 */
#define GPIO_FLAG_PR6                          GPIO_PR_PR6                    /*!< Port interrupt pending bit set, bit 6 */
#define GPIO_FLAG_PR7                          GPIO_PR_PR7                    /*!< Port interrupt pending bit set, bit 7 */
#define GPIO_FLAG_PR8                          GPIO_PR_PR8                    /*!< Port interrupt pending bit set, bit 8 */
#define GPIO_FLAG_PR9                          GPIO_PR_PR9                    /*!< Port interrupt pending bit set, bit 9 */
#define GPIO_FLAG_PR10                        GPIO_PR_PR10                   /*!< Port interrupt pending bit set, bit 10 */
#define GPIO_FLAG_PR11                        GPIO_PR_PR11                   /*!< Port interrupt pending bit set, bit 11 */
#define GPIO_FLAG_PR12                        GPIO_PR_PR12                   /*!< Port interrupt pending bit set, bit 12 */
#define GPIO_FLAG_PR13                        GPIO_PR_PR13                   /*!< Port interrupt pending bit set, bit 13 */
#define GPIO_FLAG_PR14                        GPIO_PR_PR14                   /*!< Port interrupt pending bit set, bit 14 */
#define GPIO_FLAG_PR15                        GPIO_PR_PR15                   /*!< Port interrupt pending bit set, bit 15 */

/** @brief  AF Primary selection **/
#define GPIO_AFS_Primary     ((uint8_t)0x00)

#define IS_GPIO_AF(AF)   (((AF) == AFIO_AF_0) || ((AF) == AFIO_AF_1) ||  ((AF) == AFIO_AF_2) || ((AF) == AFIO_AF_3) || \
                          			((AF) == AFIO_AF_4) || ((AF) == AFIO_AF_5) || ((AF) == AFIO_AF_6))


/** @addtogroup GPIO
  * @{
  */
  
/* Exported types ------------------------------------------------------------*/

#define IS_GPIO_ALL_PERIPH(PERIPH)	(((PERIPH) == GPIOA) || \
									((PERIPH) == GPIOB) || \
									((PERIPH) == GPIOC) || \
									((PERIPH) == GPIOD))
									
#define IS_AFIO_ALL_PERIPH(PERIPH)	(((PERIPH) == AFIOA) || \
									((PERIPH) == AFIOB) || \
									((PERIPH) == AFIOC) || \
									((PERIPH) == AFIOD))

#define IS_AFIO_PIN_SEL(SEL) ((((SEL) & (u32)0xffff0000) == 0)  && ((SEL)!=(u32)0x0000))


/** @brief  AF Primary selection **/
#define IS_AFIO_AF_SEL(SEL)	(((SEL) == AFIO_AF_None) || \
							((SEL) == AFIO_AF_0) || \
							((SEL) == AFIO_AF_1) ||  \
							((SEL) == AFIO_AF_2) || \
							((SEL) == AFIO_AF_3) || \
							((SEL) == AFIO_AF_4) || \
							((SEL) == AFIO_AF_5) || \
							((SEL) == AFIO_AF_6))

/* Exported macro ------------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */
void GPIO_Init(GPIO_TypeDef* CMSDK_Px, GPIO_InitTypeDef* GPIO_InitStruct);
void GPIO_StructInit(GPIO_InitTypeDef* GPIO_InitStruct);
void GPIO_AnaRemapConfig(AFIO_TypeDef* AFIOx, u32 AFIO_Pin, FunctionalState NewState);
uint8_t GPIO_ReadInputDataBit(GPIO_TypeDef* CMSDK_Px, u16 GPIO_Pin);
u16 GPIO_ReadInputData(GPIO_TypeDef* CMSDK_Px);
uint8_t GPIO_ReadOutputDataBit(GPIO_TypeDef* CMSDK_Px, u16 GPIO_Pin);
u16 GPIO_ReadOutputData(GPIO_TypeDef* CMSDK_Px);
void GPIO_SetBits(GPIO_TypeDef* GPIOx, u32 GPIO_Pin);
void GPIO_ResetBits(GPIO_TypeDef* GPIOx, u32 GPIO_Pin);
void GPIO_WriteBit(GPIO_TypeDef* GPIOx, u32 GPIO_Pin, BitAction BitVal);
void GPIO_Write(GPIO_TypeDef* CMSDK_Px, u16 PortVal);
void GPIO_ReverseBits(GPIO_TypeDef* GPIOx, u32 GPIO_Pin);
void GPIO_DigRemapConfig(AFIO_TypeDef* AFIOx, u16 AFIO_Pin, u8 AFIO_AF, FunctionalState NewState);
void GPIO_ClearPinAF(AFIO_TypeDef* AFIO_Px, u16 AFIO_Pin);
void GPIO_PullUpConfig(GPIO_TypeDef* CMSDK_Px, u32 GPIO_Pin, FunctionalState NewState);
void GPIO_PullDownConfig(GPIO_TypeDef* CMSDK_Px, u32 GPIO_Pin, FunctionalState NewState);
void GPIO_PinAFClear(GPIO_TypeDef* CMSDK_Px,u16 GPIO_Pin);
void GPIO_LowByte_SetBit(GPIO_TypeDef* CMSDK_Px, u16 GPIO_Pin);
void GPIO_LowByte_ClrBit(GPIO_TypeDef* CMSDK_Px, u16 GPIO_Pin);
void GPIO_LowByte_WriteBit(GPIO_TypeDef* CMSDK_Px, u16 GPIO_Pin,uint8_t bitDat);
void GPIO_HigByte_SetBit(GPIO_TypeDef* CMSDK_Px, u16 GPIO_Pin);
void GPIO_HigByte_ClrBit(GPIO_TypeDef* CMSDK_Px, u16 GPIO_Pin);
void GPIO_HigByte_WriteBit(GPIO_TypeDef* CMSDK_Px, u16 GPIO_Pin,u16 bitDat);
/**
  * @}
  */

  
#ifdef __cplusplus
}
#endif

#endif 


