 /******************************************************************************
  * @file    PT32x033x_i2c.h
  * @author  ӦÿŶ
  * @version V1.4.0
  * @date    2023/10/27
  * @brief    This file contains all the functions prototypes for the I2C firmware library.
  *          
  ******************************************************************************
  * @attention
  *
  *
  *****************************************************************************/


/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef PT32x033x_I2C_H
#define PT32x033x_I2C_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x033x.h"


/** @addtogroup I2C
  * @{
  */
  
/* Exported types ------------------------------------------------------------*/


/** @brief  I2C Init structure definition **/
typedef struct
{
	u32 I2C_BaudRatePrescaler;	/*!< IIC frequency division: minimum 20, maximum 4096*/
	u32 I2C_BroadCast;			/*!< Specifies the I2C mode.
								This parameter can be a value of @ref I2C_mode*/
	u32 I2C_OwnAddress;	/*!< Specifies the device own address.
                                         			This parameter can be a 7-bit or 10-bit address*/
	u32 I2C_ACK;          		/*!< Enables or disables the acknowledgement.
								This parameter can be a value of @ref I2C_acknowledgement*/
}I2C_InitTypeDef;



/** @defgroup IS_I2C_ALL_PERIPH **/
#define IS_I2C_ALL_PERIPH(PERIPH)       ((PERIPH) == I2C)

/** @defgroup IS_I2C_BC_SEL **/
#define  I2C_BroadCast_Enable			I2C_OAR_BC
#define  I2C_BroadCast_Disable			((u32)0x00000000)
#define IS_I2C_BC_SEL(SEL)	(((SEL) == I2C_BroadCast_Enable) || \
							((SEL) == I2C_BroadCast_Disable))	

/** @defgroup I2C_acknowledgement **/
#define  I2C_ACK_Enable			I2C_CR_ACK
#define  I2C_ACK_Disable			((u32)0x00000000)
#define IS_I2C_ACK_SEL(SEL)	(((SEL) == I2C_ACK_Enable) || \
							((SEL) == I2C_ACK_Disable))
                                         
/** @defgroup I2C_Prescaler **/
#define IS_I2C_BR_VAL(Value)	(((Value) >= 5)  && ((Value) < 1024))

/** @defgroup IS_I2C_ADDR_VAL **/
#define IS_I2C_ADDR_VAL(Value)   ((Value) <128)

/** @defgroup I2C_acknowledgement **/
#define I2C_FLAG_Stop 0x00				/* ϳһֹͣź*/
#define I2C_FLAG_StartOk 0x01			/* ʼźŷ*/
#define I2C_FLAG_ReStartOk 0x02			/* ظʼźŷ*/
#define I2C_FLAG_MASGetAckW 0x03		/*  ַַϣ յ ACK*/
#define I2C_FLAG_MASGetNackW 0x04		/*  ַַϣ յ NACK*/
#define I2C_FLAG_MDSGetAck 0x05		/*  ַϣ յ ACK*/
#define I2C_FLAG_MDSGetNack 0x06		/*  ַϣ յ NACK*/
#define I2C_FLAG_MArbitrationlost  0x07	/*  ٲʧ*/
#define I2C_FLAG_MASGetAckR 0x08		/*  ַַϣ յ ACK*/
#define I2C_FLAG_MASGetNackR 0x09		/*  ַַϣ յ NACK*/
#define I2C_FLAG_MDGSendAck 0x0A		/*  ֽϣ  ACK*/
#define I2C_FLAG_MDGSendNack 0x0B		/*  ֽϣ  NACK*/

#define I2C_FLAG_SAGSendAckW 0x0C		/* ӻ ַֽϣ  ACK*/
#define I2C_FLAG_SALAGSendAckW 0x0D	/* ӻٲʧתĴӻ ַֽϣ  ACK*/
#define I2C_FLAG_SBCAGSendAck 0x0E		/* ӻ㲥ַֽϣ  ACK*/
#define I2C_FLAG_SALBCAGSendAck 0x0F	/* ӻٲʧתĴӻ㲥ַֽϣ  ACK*/
#define I2C_FLAG_SDGSendAck 0x10	/* ӻ ֽϣ  ACK*/
#define I2C_FLAG_SDGSendNack 0x11	/* ӻ ֽϣ  NACK*/
#define I2C_FLAG_SBCDGSendAck 0x12	/* ӻ 㲥ֽϣ  ACK*/
#define I2C_FLAG_SBCDGSendNack 0x13/* ӻ 㲥ֽϣ  NACK*/
#define I2C_FLAG_SDGGSRS 0x14		/* ӻ ֽϣ յֹͣźŻظʼź*/
#define I2C_FLAG_SAGSendAckR 0x15	/* ӻ ַֽϣ  ACK*/
#define I2C_FLAG_SALAGSendAckR 0x16		/* ӻ ٲʧתĴӻ,ַֽϣ  ACK*/
#define I2C_FLAG_SDSReadAck 0x17	/* ӻ ַϣ յ ACK*/
#define I2C_FLAG_SDSReadNack 0x18	/* ӻ ַϣ յ NACK*/
#define I2C_FLAG_SDSSAGSRS 0x19		/* ӻ ֽϣ  ACK 󡢽յֹͣźŻظʼź*/
#define I2C_FLAG_IDLE 0x1f			/* ߿*/

#define IS_I2C_SR_SEL(SEL)	(((SEL) == I2C_FLAG_Stop) || \
							((SEL) == I2C_FLAG_StartOk) || \
							((SEL) == I2C_FLAG_ReStartOk) || \
							((SEL) == I2C_FLAG_MASGetAckW) || \
							((SEL) == I2C_FLAG_MASGetNackW) || \
							((SEL) == I2C_FLAG_MDSGetAck) || \
							((SEL) == I2C_FLAG_MDSGetNack) || \
							((SEL) == I2C_FLAG_MArbitrationlost) || \
							((SEL) == I2C_FLAG_MASGetAckR) || \
							((SEL) == I2C_FLAG_MASGetNackR) || \
							((SEL) == I2C_FLAG_MDGSendAck) || \
							((SEL) == I2C_FLAG_MDGSendNack) || \
							((SEL) == I2C_FLAG_SAGSendAckW) || \
							((SEL) == I2C_FLAG_SALAGSendAckW) || \
							((SEL) == I2C_FLAG_SBCAGSendAck) || \
							((SEL) == I2C_FLAG_SALBCAGSendAck) || \
							((SEL) == I2C_FLAG_SDGSendAck) || \
							((SEL) == I2C_FLAG_SDGSendNack) || \
							((SEL) == I2C_FLAG_SBCDGSendAck) || \
							((SEL) == I2C_FLAG_SBCDGSendNack) || \
							((SEL) == I2C_FLAG_SDGGSRS) || \
							((SEL) == I2C_FLAG_SAGSendAckR) || \
							((SEL) == I2C_FLAG_SALAGSendAckR) || \
							((SEL) == I2C_FLAG_SDSReadAck) || \
							((SEL) == I2C_FLAG_SDSReadNack) || \
							((SEL) == I2C_FLAG_SDSSAGSRS) || \
							((SEL) == I2C_FLAG_IDLE))


/* Exported macro ------------------------------------------------------------*/
/* Exported functions ---------------------------------------------------------*/
void I2C_Init(I2C_TypeDef* I2Cx, I2C_InitTypeDef* I2C_InitStruct);
void I2C_StructInit(I2C_InitTypeDef* I2C_InitStruct);
void I2C_Cmd(I2C_TypeDef* I2Cx, FunctionalState NewState);
void I2C_GenerateSTART(I2C_TypeDef* I2Cx, FunctionalState NewState);
void I2C_GenerateSTOP(I2C_TypeDef* I2Cx, FunctionalState NewState);
void I2C_AcknowledgeConfig(I2C_TypeDef* I2Cx, FunctionalState NewState);
void I2C_SendData(I2C_TypeDef* I2Cx, u8 Data);
void I2C_SendAddr(I2C_TypeDef* I2Cx, u8 Data);
u8 I2C_ReceiveData(I2C_TypeDef* I2Cx);
FlagStatus I2C_GetStatus(I2C_TypeDef* I2Cx, u16 I2C_FLAG);
/**
  * @}
  */

  
#ifdef __cplusplus
}
#endif

#endif 


