 /******************************************************************************
  * @file    PT32x033x_ifmc.h
  * @author  ӦÿŶ
  * @version V1.4.0
  * @date    2023/10/27
  * @brief    This file contains all the functions prototypes for the IFMC firmware library.
  *          
  ******************************************************************************
  * @attention
  *
  *
  *****************************************************************************/

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef PT32x033x_IFMC_H
#define PT32x033x_IFMC_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x033x.h"


/** @addtogroup IFMC
  * @{
  */

/* Exported types ------------------------------------------------------------*/


/**  @brief  IFMC Status **/ 
typedef enum
{	
	IFMC_WriteOver=1,
	IFMC_ProgramOver,
	IFMC_ChipEraseOver,
	IFMC_Busy,
	IFMC_CommandError,
	IFMC_KeyError,
	IFMC_AddrError,
	IFMC_Complete,
	IFMC_TimeOut
}IFMC_Status;

/* Exported constants --------------------------------------------------------*/

/** @defgroup IFMC_Latency  **/ 
#define IFMC_LatencyCycle_0                ((u32)0x00000000)  /*!< IFMC Zero Latency cycle */
#define IFMC_LatencyCycle_1                IFMC_CR_WAIT       /*!< IFMC One Latency cycle */
#define IS_FLASH_WAIT_SEL(LATENCY) 	(((LATENCY) == IFMC_LatencyCycle_0) || \
										((LATENCY) == IFMC_LatencyCycle_1))

/** @defgroup IFMC_Interrupts  **/ 
#define IS_IFMC_IT(IT) ((IT<= 0x7F) && (IT!=0x08))

/** @defgroup IS_FLASH_PSC_Value  **/ 
#define IS_IFMC_PSC_Value(Value) ((Value< 64) )


/** @defgroup IFMC_Address  **/ 
#define IFMC_PAGE_SIZE    ((u16)0x200)	 /*!< 512B */
#define MAINCODE_START_ADDR  ((u32)0x00000000)


#if defined(PT32x033x6x6)
	#define MAINCODE_END_ADDR    ((u32)0x00008000) 
#elif defined(PT32x033x8x6)
	#define MAINCODE_END_ADDR    ((u32)0x0000F000) 
#else
	#error "Please select CHIP used in your application (in PT32x033x_ifmc.h file)"
#endif


/** @brief  IFMC EncryptedArea addr **/ 
#define EncryptedArea0_StartAddr	   ((u32)0x0000EFFF)
#define EncryptedArea0_EndAddr	     ((u32)0x0000F1FF)

#define EncryptedArea1_StartAddr     ((u32)0x0000F1FF)
#define EncryptedArea1_EndAddr       ((u32)0x0000F3FF)

#define EncryptedArea2_StartAddr     ((u32)0x0000F3FF)
#define EncryptedArea2_EndAddr       ((u32)0x0000F5FF)

#define EncryptedArea3_StartAddr     ((u32)0x0000F5FF)
#define EncryptedArea3_EndAddr       ((u32)0x0000F7FF)

#define EncryptedArea4_StartAddr     ((u32)0x0000F7FF)
#define EncryptedArea4_EndAddr       ((u32)0x0000F9FF)

#define EncryptedArea5_StartAddr     ((u32)0x0000F9FF)
#define EncryptedArea5_EndAddr       ((u32)0x0000FBFF)

#define EncryptedArea6_StartAddr     ((u32)0x0000FBFF)
#define EncryptedArea6_EndAddr       ((u32)0x0000FDFF)

#define EncryptedArea7_StartAddr     ((u32)0x0000FDFF)
#define EncryptedArea7_EndAddr       ((u32)0x0000FFFF)

#define EncryptedArea_StartAddr      ((u32)0x0000EFFF)
#define EncryptedArea_EndAddr        ((u32)0x0000FFFF)
#define IS_IFMC_PROGRAM_ADDRESS(ADDRESS)   ((ADDRESS) < EncryptedArea_EndAddr)


/** @defgroup IFMC_Flags  **/ 
#define IFMC_FLAG_WOV	IFMC_SR_WOV	/*!< IFMC дɱ־ */
#define IFMC_FLAG_POV	IFMC_SR_POV   	/*!< IFMCɱ־ */
#define IFMC_FLAG_COV	IFMC_SR_COV  	/*!< IFMCⱣʱɱ־ */
#define IFMC_FLAG_BUSY	IFMC_SR_BUSY	/*!< IFMC־*/
#define IFMC_FLAG_CERR	IFMC_SR_CERR	/*!< IFMC־*/
#define IFMC_FLAG_KERR	IFMC_SR_KERR	/*!< IFMC־*/
#define IFMC_FLAG_AERR	IFMC_SR_AERR	/*!< IFMCַ־ */
#define IS_IFMC_SR_SEL(SEL) ((((SEL) & (u16)0xff00) == 0) && ((SEL) != (u16)0x00))
#define IS_IFMC_SR_GET(FLAG)  (((FLAG) == IFMC_FLAG_WOV) || \
								((FLAG) == IFMC_FLAG_POV) || \
								((FLAG) == IFMC_FLAG_COV) || \
								((FLAG) == IFMC_FLAG_BUSY) || \
								((FLAG) == IFMC_FLAG_CERR) || \
								((FLAG) == IFMC_FLAG_KERR) || \
								((FLAG) == IFMC_FLAG_AERR))

/** @defgroup IFMC_Timeout_definition  **/ 
#define IFMC_ER_PRG_TIMEOUT         ((u32)0x000B0000)


/** @brief  IFMC Operation Commands **/ 
#define IFMC_Programming	((u32)0x00000000) 
#define IFMC_PageErase		((u32)0x00000002)
#define IFMC_MainCodeErase	((u32)0x00000004)
#define IFMC_WriteOperation	IFMC_CR_MODE
#define IFMC_ReadOperation	((u32)0x00000000) 
#define IFMC_OperationStarts	IFMC_CR_START


#define  IFMC_MainCodeKey		((u32)0xADEB0000)   
#define  IFMC_EncryptedArea0Key	((u32)0x2D570000)  
#define  IFMC_EncryptedArea1Key	((u32)0x58B40000)   
#define  IFMC_EncryptedArea2Key	((u32)0x63F20000)   
#define  IFMC_EncryptedArea3Key	((u32)0xDC490000)   
#define  IFMC_EncryptedArea4Key	((u32)0x59BD0000) 
#define  IFMC_EncryptedArea5Key	((u32)0x37A10000) 
#define  IFMC_EncryptedArea6Key	((u32)0x4BF00000)  
#define  IFMC_EncryptedArea7Key	((u32)0x71C30000)  


/* Exported macro ------------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */
void IFMC_SetLatency(u32 IFMC_Latency);
void IFMC_SetPrescaler(u8 Prescaler);
IFMC_Status IFMC_GetFlashStatus(void);
IFMC_Status IFMC_WaitForLastOperation(u32 Timeout);

IFMC_Status IFMC_ErasePage(u32 Page_Address);
IFMC_Status IFMC_EraseAllPages(void);
IFMC_Status IFMC_ProgramWord(u32 Address, u32 Data);

u32 IFMC_ReadWord(u32 Address);
u16 IFMC_ReadHalfWord(u32 Address);
u8 IFMC_ReadByte(u32 Address);
void IFMC_ResetRemapBit(void);
void IFMC_ITConfig(u32 IFMC_IT, FunctionalState NewState);
FlagStatus IFMC_GetFlagStatus(u32 IFMC_FLAG);
void IFMC_ClearFlag(u32 IFMC_FLAG);
RemapStatus IFMC_GetBootStatus(void);
ProtectStatus IFMC_GetReadProtectStatus(void);

/**
  * @}
  */

  
#ifdef __cplusplus
}
#endif

#endif 
