  /******************************************************************************
  * @file    PT32x033x_lcd.h
  * @author  ӦÿŶ
  * @version V1.4.0
  * @date    2023/10/27
  * @brief    This file contains all the functions prototypes for the LCD firmware library.
  *          
  ******************************************************************************
  * @attention
  *
  *
  *****************************************************************************/


/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef PT32x033x_LCD_H
#define PT32x033x_LCD_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x033x.h"

/* Exported types ------------------------------------------------------------*/
typedef struct
{
	u32 LCD_DriveVoltageType;
	u32 LCD_Duty;
	u32 LCD_WaveControl;
	u32 LCD_BlinkMode;
	u32 LCD_ClkSource;
	u32 LCD_PageDisplayMode;
	u32 LCD_ChargePump;
	u32 LCD_TotalResistance;
} LCD_InitTypeDef;

/* Exported constants --------------------------------------------------------*/

/** @defgroup LCD_DriveVoltageType **/
#define LCD_DriveVoltageType_R	0x00000000  
#define LCD_DriveVoltageType_C	0x00000002
#define IS_LCD_CRTYPE_SEL(CODE)	(((CODE) == LCD_DriveVoltageType_R)  ||\
									((CODE) == LCD_DriveVoltageType_C))

/** @defgroup LCD_Duty **/
#define LCD_Duty_Div2	0x00000000
#define LCD_Duty_Div4	0x00000004   
#define LCD_Duty_Div6	0x00000008
#define LCD_Duty_Div8	0x0000000C
#define IS_LCD_DUTY_SEL(CODE)	(((CODE) == LCD_Duty_Div2)  ||\
								((CODE) == LCD_Duty_Div4)||\
								((CODE) == LCD_Duty_Div6)||\
								((CODE) == LCD_Duty_Div8))

/** @defgroup LCD_WaveControl **/
#define LCD_WaveControl_A		0x00000000
#define LCD_WaveControl_B		0x00000010
#define IS_LCD_WAVE_SEL(CODE)	(((CODE) == LCD_WaveControl_A)  ||\
								((CODE) == LCD_WaveControl_B))

/** @defgroup LCD_BlinkMode **/
#define LCD_BlinkMode_Disable	0x00000000
#define LCD_BlinkMode_Enable	0x00000020  
#define IS_LCD_BLINK_SEL(CODE) (((CODE) == LCD_BlinkMode_Disable)  ||\
								((CODE) == LCD_BlinkMode_Enable))

/** @defgroup LCD_ClkSource **/
#define LCD_ClkSource_LCDI		0x00000000
#define LCD_ClkSource_LSE		0x00000040  
#define IS_LCD_CLK_SEL(CODE)	(((CODE) == LCD_ClkSource_LCDI)  ||\
								((CODE) == LCD_ClkSource_LSE))

/** @defgroup LCD_PageDisplayMode **/
#define LCD_PageDisplayMode_Fixed		0x00000000
#define LCD_PageDisplayMode_Round		0x00001000  
#define LCD_PageDisplayMode_RoundOFF	0x00002000  
#define LCD_PageDisplayMode_Continue	0x00003000  
#define IS_LCD_DMOD_SEL(CODE)	(((CODE) == LCD_PageDisplayMode_Fixed)  ||\
								((CODE) == LCD_PageDisplayMode_Round)||\
								((CODE) == LCD_PageDisplayMode_RoundOFF)||\
								((CODE) == LCD_PageDisplayMode_Continue))

/** @defgroup LCD_ChargePump **/
#define LCD_ChargePump_Disable	0x00000000
#define LCD_ChargePump_Enable	0x00004000  
#define IS_LCD_CAPMODE_SEL(CODE)	(((CODE) == LCD_ChargePump_Disable)  ||\
									((CODE) == LCD_ChargePump_Enable))

/** @defgroup LCD_TotalResistance **/
#define LCD_TotalResistance_45k	0x00000000
#define LCD_TotalResistance_360k	0x00008000  
#define IS_LCD_RES_SEL(CODE)	(((CODE) == LCD_TotalResistance_45k)  ||\
								((CODE) == LCD_TotalResistance_360k))


/** @defgroup IS_LCD_Page_SEL **/
#define LCD_Page_0	0	
#define LCD_Page_1	1	
#define LCD_Page_2	2	
#define LCD_Page_3	3
#define LCD_Page_4	4	
#define LCD_Page_5	5	
#define LCD_Page_6	6	
#define LCD_Page_7	7	
#define LCD_Page_8	8	
#define LCD_Page_9	9		
#define LCD_Page_10	10	
#define LCD_Page_11	11	
#define LCD_Page_12	12
#define LCD_Page_13	13	
#define LCD_Page_14	14
#define LCD_Page_15	15
#define IS_LCD_Page_SEL(CODE)	(((CODE) == LCD_Page_0)  || ((CODE) == LCD_Page_1)||\
								((CODE) == LCD_Page_2) || ((CODE) == LCD_Page_3)||\
								((CODE) == LCD_Page_4) || ((CODE) == LCD_Page_5)||\
								((CODE) == LCD_Page_6) || ((CODE) == LCD_Page_7)||\
								((CODE) == LCD_Page_8) || ((CODE) == LCD_Page_9)||\
								((CODE) == LCD_Page_10) || ((CODE) == LCD_Page_11)||\
 								((CODE) == LCD_Page_12) || ((CODE) == LCD_Page_13)||\
								((CODE) == LCD_Page_14)|| ((CODE) == LCD_Page_15))

/** @defgroup IS_LCD_PIN_SEL **/
#define LCD_PIN_0	0	
#define LCD_PIN_1	1	
#define LCD_PIN_2	2	
#define LCD_PIN_3	3
#define LCD_PIN_4	4	
#define LCD_PIN_5	5	
#define LCD_PIN_6	6	
#define LCD_PIN_7	7	
#define LCD_PIN_8	8	
#define LCD_PIN_9	9		
#define LCD_PIN_10	10	
#define LCD_PIN_11	11	
#define LCD_PIN_12	12
#define LCD_PIN_13	13	
#define LCD_PIN_14	14
#define LCD_PIN_15	15
#define LCD_PIN_16	16	
#define LCD_PIN_17	17	
#define LCD_PIN_18	18	
#define LCD_PIN_19	19
#define LCD_PIN_20	20	
#define LCD_PIN_21	21	
#define LCD_PIN_22	22	
#define LCD_PIN_23	23	
#define LCD_PIN_24	24	
#define LCD_PIN_25	25		
#define LCD_PIN_26	26	
#define LCD_PIN_27	27	
#define LCD_PIN_28	28
#define LCD_PIN_29	29	
#define LCD_PIN_30	30
#define LCD_PIN_31	31
#define IS_LCD_PIN_SEL(CODE)	(((CODE) == LCD_PIN_0)  || ((CODE) == LCD_PIN_1)||\
								((CODE) == LCD_PIN_2) || ((CODE) == LCD_PIN_3)||\
								((CODE) == LCD_PIN_4) || ((CODE) == LCD_PIN_5)||\
								((CODE) == LCD_PIN_6) || ((CODE) == LCD_PIN_7)||\
								((CODE) == LCD_PIN_8) || ((CODE) == LCD_PIN_9)||\
								((CODE) == LCD_PIN_10) || ((CODE) == LCD_PIN_11)||\
 								((CODE) == LCD_PIN_12) || ((CODE) == LCD_PIN_13)||\
								((CODE) == LCD_PIN_14)|| ((CODE) == LCD_PIN_15)||\
								((CODE) == LCD_PIN_16)|| ((CODE) == LCD_PIN_17)||\
								((CODE) == LCD_PIN_18)|| ((CODE) == LCD_PIN_19)||\
								((CODE) == LCD_PIN_20)|| ((CODE) == LCD_PIN_21)||\
								((CODE) == LCD_PIN_22)|| ((CODE) == LCD_PIN_23)||\
								((CODE) == LCD_PIN_24)|| ((CODE) == LCD_PIN_25)||\
								((CODE) == LCD_PIN_26)|| ((CODE) == LCD_PIN_27)||\
								((CODE) == LCD_PIN_28)|| ((CODE) == LCD_PIN_29)||\
								((CODE) == LCD_PIN_30)|| ((CODE) == LCD_PIN_31))

/** @defgroup IS_LCD_COM_SEL **/
#define LCD_COM_0	0x01
#define LCD_COM_1	0x02	
#define LCD_COM_2	0x04	
#define LCD_COM_3	0x08
#define LCD_COM_4	0x10
#define LCD_COM_5	0x20	
#define LCD_COM_6	0x40
#define LCD_COM_7	0x80
#define IS_LCD_COM_SEL(CODE)	(((CODE) == LCD_COM_0)  || ((CODE) == LCD_COM_1)||\
								((CODE) == LCD_COM_2) || ((CODE) == LCD_COM_3)||\
								((CODE) == LCD_COM_4) || ((CODE) == LCD_COM_5)||\
								((CODE) == LCD_COM_6) || ((CODE) == LCD_COM_7))


#define LCD_Grayscale100	((u16)0x000E)
#define LCD_Grayscale92		((u16)0x000C)
#define LCD_Grayscale85		((u16)0x000A)
#define LCD_Grayscale80		((u16)0x0008)
#define LCD_Grayscale75		((u16)0x0006) 
#define LCD_Grayscale70		((u16)0x0004) 
#define LCD_Grayscale66		((u16)0x0002) 
#define LCD_Grayscale63		((u16)0x0000) 
#define IS_LCD_GDR(IT)	(((IT) == LCD_Grayscale100) || ((IT) == LCD_Grayscale92) || \
						((IT) == LCD_Grayscale85)|| ((IT) == LCD_Grayscale80) || \
						((IT) == LCD_Grayscale75)|| ((IT) == LCD_Grayscale70)|| \
						((IT) == LCD_Grayscale66) || ((IT) == LCD_Grayscale63))	//one by one
						
#define LCD_DriveType_C LCD_CR_TYPE
#define LCD_DriveType_R	0x00000000
#define IS_LCD_DRIVE_TYPE(TYPE) ((TYPE) == LCD_DriveType_C) || ((TYPE) == LCD_DriveType_R)


/* Exported macro ------------------------------------------------------------*/
/* Exported functions ---------------------------------------------------------*/
void LCD_Init(LCD_InitTypeDef* LCD_InitStruct);
void LCD_StructInit(LCD_InitTypeDef* LCD_InitStruct);
void LCD_ClearDRAM(void);
void LCD_ClearPage(u32 Page_Data);
void LCD_SetDramCOM(u32 LCD_PIN,u32 LCD_COM,FunctionalState NEWState);
void LCD_CMD(FunctionalState NewState);
void LCD_UpdataCMD(FunctionalState NewState);
void LCD_AllLightsOnCMD(FunctionalState NewState);
void LCD_AllLightsOffCMD(FunctionalState NewState);
void LCD_GrayscaleCMD(FunctionalState NewState);
void LCD_Grayscale(uint16_t Gray_Rate);
void LCD_DriveTypeConfig(u32 LCD_Type);
void Wait_LCD(void);
/**
  * @}
  */

  
#ifdef __cplusplus
}
#endif

#endif 


