/******************************************************************************
  * @file    PT32x033x_opa.h
  * @author  ӦÿŶ
  * @version V1.4.0
  * @date    2023/10/27
  * @brief    This file contains all the functions prototypes for the OPA/OPA firmware library
  *
  ******************************************************************************
  * @attention
  *
  *
  *****************************************************************************/


/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef PT32x033x_OPA_H
#define PT32x033x_OPA_H

#ifdef __cplusplus
extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x033x.h"

/** @addtogroup Analog comparators and operational amplifiers
  * @{
  */

/* Exported types ------------------------------------------------------------*/

/** @brief  OPA Init structure definition **/
typedef struct
{
	u32 OPA_PositiveInput;	/*!< */
	u32 OPA_PowerMode;
} OPA_InitTypeDef;

#define OPA_TrimValue 	OPA_CR2_TRIM

/* Exported constants --------------------------------------------------------*/

/** @defgroup OPAOPA_Exported_Constants **/
#define IS_OPA_ALL_PERIPH(PERIPH)               (((PERIPH) == OPA0) || ((PERIPH) == OPA1))
#define IS_OPA_INITDELAY_VALUE(VALUE) ((VALUE) <= 0x3FFF)
#define IS_OPA_DAC_VALUE(VALUE)       ((VALUE) <= 0x1F)

#define OPA0_AFOutput1	OPA_CR2_AFO1E
#define OPA0_AFOutput2	OPA_CR2_AFO2E
#define OPA0_AFOutput3	OPA_CR2_AFO3E
#define IS_OPA0_AFOx(SEL)	((SEL==OPA0_AFOutput1)||\
							(SEL==OPA0_AFOutput2)||\
							(SEL==OPA0_AFOutput3))



/** @defgroup OPA_FEFSEL **/
#define	OPA_PositiveInput_OPAxP		(OPA_CR1_OPS&0x00)   /*!< */
#define	OPA_PositiveInput_LDAC		(OPA_CR1_OPS&0x04)   /*!<*/
#define	OPA_PositiveInput_DAC		(OPA_CR1_OPS&0x0C)
#define	OPA_PositiveInput_BG1V0		(OPA_CR1_OPS&0x08)   /*!<*/
#define IS_OPA_PositiveInput(SOURCE)		(((SOURCE) == OPA_PositiveInput_OPAxP) ||\
										((SOURCE) == OPA_PositiveInput_LDAC) ||\
										((SOURCE) == OPA_PositiveInput_BG1V0)||\
										((SOURCE) == OPA_PositiveInput_DAC))

#define OPA_PowerMode_HighSpeed	((u8)0x1)
#define OPA_PowerMode_LowPower	((u8)0x0)
#define IS_OPA_PowerMode(MODE) ((MODE==OPA_PowerMode_HighSpeed)||(MODE==OPA_PowerMode_LowPower))


#define IS_OPA_CLEAR_FLAG(FLAG)  (((FLAG) != (u32)RESET) && (((FLAG) & 0xFFFFFFF0) == (u32)RESET))


/* Exported macro ------------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */
void OPA_DeInit(OPA_TypeDef* OPAx);
void OPA_Init(OPA_TypeDef* OPAx, OPA_InitTypeDef* OPA_InitStruct);
void OPA_StructInit(OPA_InitTypeDef* OPA_InitStruct);
void OPA_Cmd(OPA_TypeDef* OPAx, FunctionalState NewState);
void OPA0_AFGndCMD(FunctionalState NewState);
void OPA0_AFOutputCMD(u32 OPA0_AFOx,FunctionalState NewState);

/**
  * @}
  */
  
#ifdef __cplusplus
}
#endif

#endif

