/**
  ******************************************************************************
  * @file    PT32x033x_pwr.h
  * @author  ӦÿŶ
  * @version V1.4.0
  * @date    2023/10/27
  * @brief   This file contains all the functions prototypes for the PWR firmware 
  *          library.
  ******************************************************************************
  * @attention
  *
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef PT32x033x_PWR_H
#define PT32x033x_PWR_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x033x.h"

/** @addtogroup PT32F0xx_StdPeriph_Driver
  * @{
  */

/** @addtogroup PWR
  * @{
  */ 

/* Exported types ------------------------------------------------------------*/

/* Exported constants --------------------------------------------------------*/

/** @defgroup PWR_Exported_Constants
  * @{
  */ 

/** @defgroup PWR_PVD_detection_level 
  * @brief   
  * @{
  */ 

#define PWR_PVDLevel_0		(PWR_PVDR_PLS&0x02)		// 1.7V
#define PWR_PVDLevel_1		(PWR_PVDR_PLS&0x00)		// 2.0V
#define PWR_PVDLevel_2		(PWR_PVDR_PLS&0x04)		// 2.2V
#define PWR_PVDLevel_3		(PWR_PVDR_PLS&0x06)		// 2.5V
#define PWR_PVDLevel_4		(PWR_PVDR_PLS&0x08)		// 2.75V
#define PWR_PVDLevel_5		(PWR_PVDR_PLS&0x0A)		// 3.0V
#define PWR_PVDLevel_6		(PWR_PVDR_PLS&0x0C)		// 3.5V
#define PWR_PVDLevel_7		(PWR_PVDR_PLS&0x0E)		// 4.0V

#define IS_PWR_PVD_LEVEL(LEVEL) (((LEVEL) == PWR_PVDLevel_0) || ((LEVEL) == PWR_PVDLevel_1)|| \
                                 ((LEVEL) == PWR_PVDLevel_2) || ((LEVEL) == PWR_PVDLevel_3)|| \
                                 ((LEVEL) == PWR_PVDLevel_4) || ((LEVEL) == PWR_PVDLevel_5)|| \
                                 ((LEVEL) == PWR_PVDLevel_6) || ((LEVEL) == PWR_PVDLevel_7))
/**
  * @}
  */



/** @defgroup PWR_SLEEP_mode_entry 
  * @{
  */

#define PWR_SLEEPEntry_WFI              ((uint8_t)0x01)
#define PWR_SLEEPEntry_WFE              ((uint8_t)0x02)
#define IS_PWR_SLEEP_ENTRY(ENTRY) (((ENTRY) == PWR_SLEEPEntry_WFI) || ((ENTRY) == PWR_SLEEPEntry_WFE))
 
/**
  * @}
  */

/** @defgroup PWR_STOP_mode_entry 
  * @{
  */

#define PWR_STANDBYEntry_WFI               ((uint8_t)0x01)
#define PWR_STANDBYEntry_WFE               ((uint8_t)0x02)
#define IS_PWR_STANDBY_ENTRY(ENTRY) (((ENTRY) == PWR_STANDBYEntry_WFI) || ((ENTRY) == PWR_STANDBYEntry_WFE))
 
/**
  * @}
  */


/**
  * @}
  */

/* Exported macro ------------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */
void PWR_PVDLevelConfig(u32 PWR_PVDLevel);
void PWR_PVDCmd(FunctionalState NewState);
void PWR_BG2VCmd(FunctionalState NewState);
void PWR_EnterSleepMode(uint8_t PWR_SLEEPEntry);
void PWR_EnterSTANDBYMode(uint8_t PWR_DeepStandbyEntry);

#ifdef __cplusplus
}
#endif

#endif /* __PT32F0XX_PWR_H */

/**
  * @}
  */

/**
  * @}
  */

/************************ (C) *****END OF FILE****/
