  /******************************************************************************
  * @file    PT32x033x_rcc.h
  * @author  ӦÿŶ
  * @version V1.4.0
  * @date    2023/10/27
  * @brief    This file contains all the functions prototypes for the SYS firmware library.
  *          
  ******************************************************************************
  * @attention
  *
  *
  *****************************************************************************/

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef PT32x033x_RCC_H
#define PT32x033x_RCC_H

#ifdef __cplusplus
extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x033x.h"

typedef struct
{
	u32 SYSCLK_Frequency;
	u32 PCLK_Frequency;
} System_ClocksTypeDef;

/** @addtogroup SYSTEM CONTROL
  * @{
  */

#define RCC_SystemClock_HSI	(RCC_CFGR_SCW&0x00)
#define RCC_SystemClock_HSE	(RCC_CFGR_SCW&0x01)
#define RCC_SystemClock_PLL	(RCC_CFGR_SCW&0x02)
#define RCC_SystemClock_LSI	(RCC_CFGR_SCW&0x03)


#define RCC_PLLClockSource_HSI	(RCC_CFGR_PLLSRC&0x00)
#define RCC_PLLClockSource_HSE	(RCC_CFGR_PLLSRC&0x04)
#define RCC_PLLClockSource_LSI	(RCC_CFGR_PLLSRC&0x0C)

/** @defgroup OSC_flags_definition **/
#define HCK_FLAG_RDY		((u32)0x00000002) 	//Hight CLK Ready Flag
#define LCK_FLAG_RDY       	((u32)0x00000001)		//Low CLK Ready Flag
#define IS_RCC_OscRdy_FLAG(FLAG) (((FLAG) == HCK_FLAG_RDY)   || ((FLAG) == LCK_FLAG_RDY))

/** @defgroup OSC_Source_definition **/
#define Oscillator_LSE	((u8)1)	//Extern Low CLK Source
#define Oscillator_HSE	((u8)2) 	//Extern Hight CLK Source
#define Oscillator_LSI	((u8)3) 	//Internal Low CLK Source
#define Oscillator_HSI	((u8)4) 	//Internal Hight CLK Source
#define IS_RCC_Osc_Source(FLAG) (((FLAG) == Oscillator_HSE)   || ((FLAG) == Oscillator_LSE) || ((FLAG) == Oscillator_HSI) || ((FLAG) == Oscillator_LSI))

/* Exported macro ------------------------------------------------------------*/

/* Exported constants --------------------------------------------------------*/
/** @brief Enumeration of Global reset status. **/

#define	RCC_FLAG_SFR    ((u32)0x00000000)
#define	RCC_FLAG_IWDG   ((u32)0x00000001)
#define	RCC_FLAG_LOCKUP ((u32)0x00000002)
#define	RCC_FLAG_SWDG   ((u32)0x00000004)
#define	RCC_FLAG_OSCR   ((u32)0x00000008)
#define	RCC_FLAG_PLLR   ((u32)0x00000010)
#define	RCC_FLAG_POR    ((u32)0x00000020)
#define	RCC_FLAG_PINR   ((u32)0x00000040)
#define	RCC_FLAG_PVDR   ((u32)0x00000080)

#define IS_RSTCU_FLAG(FLAG)       ((FLAG == RCC_FLAG_SFR)    || \
								(FLAG == RCC_FLAG_IWDG)   || \
								(FLAG == RCC_FLAG_LOCKUP)      || \
    						(FLAG == RCC_FLAG_SWDG)   || \
								(FLAG == RCC_FLAG_OSCR)|| \
								(FLAG == RCC_FLAG_PLLR)    || \
								(FLAG == RCC_FLAG_POR)     || \
								(FLAG == RCC_FLAG_PINR)    || \
								(FLAG == RCC_FLAG_PVDR)  )


/*  Definitions of APB peripheral 0 reset */
#define RCC_Reset_OREN            (1UL << 4)
#define RCC_Reset_PREN              (1UL << 5)
#define RCC_Reset_BGREN              (1UL << 6)
#define RCC_Reset_PDRE             (1UL << 8)
#define RCC_Reset_HREN            (1UL << 10)
#define IS_RSTEN_SOURCE(SOURCE)    ((SOURCE == RCC_Reset_OREN)   || \
									(SOURCE == RCC_Reset_PREN)    || \
									(SOURCE == RCC_Reset_BGREN)    || \
									(SOURCE == RCC_Reset_PDRE)   || \
									(SOURCE == RCC_Reset_HREN))

#define IS_LSECAP_RAWADJUST(value) ((value)<=15)
#define IS_LSECAP_FINEADJUST(value) ((value)<=15)
#define IS_LSECAP_SELECT(value) ((value)<=15)
/* Exported macro ------------------------------------------------------------*/
/* Exported functions ---------------------------------------------------------*/
/* Exported functions ---------------------------------------------------------*/
u32 RCC_GetSYSCLKFreq(void);
u32 RCC_GetHCLKFreq(void);
u32 RCC_GetPCLKFreq(void);
FlagStatus RCC_OscillatorReady(u32 OSC_FLAG);
FlagStatus RCC_GetResetFlagStatus(u32 RSTCU_RSTF);
void RCC_ClearResetFlag(u32 RSTCU_RSTF);
void RCC_RestConfig(u32 RstSource, FunctionalState NewState);
void RCC_OscillatorCmd(u32 OSC_Source,FunctionalState NewState);
void RCC_PLL_Cmd(FunctionalState NewState);
void RCC_Retriming(void);
void RCC_ClearAllResetFlag(void);
void  clk_source_config(void);
void  clk_pll_config(void);
void  clk_hsclk_set(void);
void  clk_mco_config(void);
u32   clk_get_sysclk(void);
void SystemInit(void);
void RCC_LSECapRawAdjust(u8 value);
void RCC_LSECapFineAdjust(u8 value);
void RCC_LSECapSelect(u8 value);

/**
  * @}
  */
  
#ifdef __cplusplus
}
#endif

#endif 

