  /******************************************************************************
  * @file    PT32x033x_rtc.h
  * @author  ӦÿŶ
  * @version V1.4.0
  * @date    2020/10/19
  * @brief    This file contains all the functions prototypes for the RTC firmware library.
  *          
  ******************************************************************************
  * @attention
  *
  *
  *****************************************************************************/

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef PT32x033x_RTC_H
#define PT32x033x_RTC_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x033x.h"

/** @addtogroup RTC
  * @{
  */ 
  
/* Exported types ------------------------------------------------------------*/
/** @brief  RTC Init structure definition **/
typedef struct
{
	u32 RTC_TimeFormat;
	u32 RTC_ClkSource;               
	u32 RTC_BeaconOut;   
	u32 RTC_TrimMode;   
} RTC_InitTypeDef;


typedef struct
{
    u8 Year;           /*!< (BCD Format)Year value */
    u8 Month;          /*!< (BCD Format)Month value */
    u8 Day;            /*!< (BCD Format)Day value */
    u8 Week;      /*!< Day of week value */
    u8 Hour;           /*!< (BCD Format)Hour value */
    u8 Minute;         /*!< (BCD Format)Minute value */
    u8 Second;         /*!< (BCD Format)Second value */
    u8 TimeFormat;      /*!< 12-Hour, 24-Hour */
	  u32 PM;           /*!<AM or PM under 12-Hour*/
} RTC_Calendar;

typedef struct
{
    u8 Hour;           /*!< (BCD Format)Hour value */
    u8 Minute;         /*!< (BCD Format)Minute value */
    u8 Second;         /*!< (BCD Format)Second value */
    u8 TimeFormat;      /*!< 12-Hour, 24-Hour */
} RTC_Alarm;

/* Exported constants --------------------------------------------------------*/

/** @defgroup IS_RTC_TF_SET **/
#define RTC_TimeFormat_12	RTC_CR_TF
#define RTC_TimeFormat_24	((u32)0x00000000)
#define  IS_RTC_TF_SET(CLOCK)	(((CLOCK) == RTC_TimeFormat_12)  ||\
								((CLOCK) == RTC_TimeFormat_24))

/** @defgroup RTC_AM_PM
* @{ 
*/
#define RTC_HOUR_AM                   0
#define RTC_HOUR_PM                   1
#define IS_RTC_AM_PM(SEL)             (((SEL) == RTC_HOUR_AM) || ((SEL) == RTC_HOUR_PM))

/** @defgroup IS_RTC_CLK_SET **/
#define RTC_ClkSource_LSE	RTC_CR_CLKS
#define RTC_ClkSource_LSI	((u32)0x00000000)
#define  IS_RTC_CLK_SET(CLOCK)	(((CLOCK) == RTC_ClkSource_LSE)  ||\
								((CLOCK) == RTC_ClkSource_LSI))

/** @defgroup IS_RTC_BEACON_SET **/
#define RTC_BeaconOut_ENABLE	RTC_CR_TBOE
#define RTC_BeaconOut_DISABLE	((u32)0x00000000)
#define  IS_RTC_BEACON_SET(CLOCK)	(((CLOCK) == RTC_BeaconOut_ENABLE)  ||\
									((CLOCK) == RTC_BeaconOut_DISABLE))

/** @defgroup IS_RTC_TME_SET **/
#define RTC_TrimMode_ENABLE	RTC_CR_TME
#define RTC_TrimMode_DISABLE	((u32)0x00000000)
#define  IS_RTC_TME_SET(CLOCK)	(((CLOCK) == RTC_TrimMode_ENABLE)  ||\
								((CLOCK) == RTC_TrimMode_DISABLE))

#define RTC_IT_CSEC		RTC_SR2_CSEC
#define RTC_IT_CMIN		RTC_SR2_CMIN 
#define RTC_IT_CHOUR	RTC_SR2_CHOUR
#define RTC_IT_DAY		RTC_SR2_DAY
#define RTC_IT_MON		RTC_SR2_MON
#define RTC_IT_ALM		RTC_SR2_ALM

#define RTC_FLAG_CSEC	RTC_SR2_CSEC
#define RTC_FLAG_CMIN	RTC_SR2_CMIN 
#define RTC_FLAG_CHOUR	RTC_SR2_CHOUR
#define RTC_FLAG_DAY	RTC_SR2_DAY
#define RTC_FLAG_MON	RTC_SR2_MON
#define RTC_FLAG_ALM	RTC_SR2_ALM

#define RTC_FLAG_UnLock		((u16)0x0040)
#define RTC_FLAG_Busy		((u16)0x0080)
#define RTC_FLAG_Lock		((u16)0x0100)
#define RTC_FLAG_UnLockSync	((u16)0x0200)
#define RTC_FLAG_LockSync	((u16)0x0400)

#define IS_RTC_SET_IT(IT) ((((IT) & (u16)0xFFC0) == 0) && ((IT) != (u16)0x00))
#define IS_RTC_GET_IT(IT) (((IT) == RTC_IT_CSEC) || ((IT) == RTC_IT_CMIN) || \
							((IT) == RTC_IT_CHOUR) || ((IT) == RTC_IT_DAY)|| \
							((IT) == RTC_IT_MON) || ((IT) == RTC_IT_ALM))
							
#define IS_RTC_GET_FLAG(IT) (((IT) == RTC_FLAG_CSEC) || ((IT) == RTC_FLAG_CMIN) || \
							((IT) == RTC_FLAG_CHOUR) || ((IT) == RTC_FLAG_DAY)|| \
							((IT) == RTC_FLAG_MON) || ((IT) == RTC_FLAG_ALM)|| \
							((IT) == RTC_FLAG_UnLock) || ((IT) == RTC_FLAG_Busy)|| \
							((IT) == RTC_FLAG_Lock) || ((IT) == RTC_FLAG_UnLockSync)|| \
							((IT) == RTC_FLAG_LockSync))
							
#define IS_RTC_CLEAR_FLAG(IT) ((((IT) & (u16)0xFFC0) == 0x00) && ((IT) != 0x00))	



/* Exported macro ------------------------------------------------------------*/
/* Exported functions ---------------------------------------------------------*/
void RTC_Init(RTC_InitTypeDef* RTC_InitStruct);
void RTC_StructInit(RTC_InitTypeDef* RTC_InitStruct);

void RTC_ITConfig(u16 RTC_IT, FunctionalState NewState);
ITStatus RTC_GetITStatus(u16 RTC_IT);

void RTC_ClearFlag(u16 RTC_FLAG);
FlagStatus RTC_GetFlagStatus(u16 RTC_FLAG);

void RTC_UnlockCMD(FunctionalState NewState);

void RTC_GetCalendarTime(RTC_Calendar * pDt);
void RTC_SetCalendarTime(RTC_Calendar * pDt);
void RTC_GetAlarmTime(RTC_Alarm * pDt);
void RTC_SetAlarmTime(RTC_Alarm * pDt);

void RTC_SetTrim(u16 Value);

void RTC_CMD(FunctionalState NewState);

/**
  * @}
  */


#ifdef __cplusplus
}
#endif

#endif 


