  /******************************************************************************
  * @file    PT32x033x_spi.h
  * @author  ӦÿŶ
  * @version V1.4.0
  * @date    2023/10/27
  * @brief    This file contains all the functions prototypes for the SPI firmware library.
  *          
  ******************************************************************************
  * @attention
  *
  *
  *****************************************************************************/

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef PT32x033x_SPI_H
#define PT32x033x_SPI_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x033x.h"

#define SPI_NSSInternalSoft_Set         SPI_CSS_SWCS

/** @addtogroup SPI
  * @{
  */

/* Exported types ------------------------------------------------------------*/

/** @brief  SPI Init structure definition   **/
typedef struct
{
  u16 SPI_Mode;                /*!< Specifies the SPI mode (Master/Slave).This parameter can be a value of @ref SPI_mode */
  u16 SPI_DataSize;            /*!< Specifies the SPI data size. This parameter can be a value of @ref SPI_data_size */
  u16 SPI_CPOL;                /*!< Specifies the serial clock steady state.This parameter can be a value of @ref SPI_Clock_Polarity */
  u16 SPI_CPHA;                /*!< Specifies the clock active edge for the bit capture.This parameter can be a value of @ref SPI_Clock_Phase */
  u16 SPI_CSS;                 /*!< Specifies whether the NSS signal is managed by hardware (NSS pin) or by software using the SSI bit. This parameter can be a value of @ref SPI_Slave_Select_management */
  u16 SPI_SWCS; 
  u16 SPI_Prescaler;   /*!< Specifies the Baud Rate prescaler value which will be
                                         used to configure the transmit and receive SCK clock.
                                         This parameter can be a value of @ref SPI_BaudRate_Prescaler
                                         @note The communication clock is derived from the master
                                               clock. The slave clock does not need to be set. */
  u16 SPI_BaudRatePrescaler; /*!< Specifies the Baud Rate prescaler value which will be
                                         used to configure the transmit and receive SCK clock.
                                         This parameter can be a value of @ref SPI_BaudRate_Prescaler
                                         @note The communication clock is derived from the master
                                               clock. The slave clock does not need to be set. */																							 
}SPI_InitTypeDef;




/* Exported constants --------------------------------------------------------*/

/** @defgroup SPI_Exported_Constants **/
#define IS_SPI_ALL_PERIPH(PERIPH) (((PERIPH) == SPI0) ||((PERIPH) == SPI1))
                                   
/** @defgroup SPI_Mode  **/
#define SPI_Mode_Master	((u16)0x0000)
#define SPI_Mode_Slave	SPI_CR2_MSM
#define IS_SPI_MSM_SEL(SEL)	(((SEL) == SPI_Mode_Master) || \
							((SEL) == SPI_Mode_Slave))

/** @defgroup SPI_DataSize **/
#define SPI_DataSize_4b	(SPI_CR1_DFF&0x03)
#define SPI_DataSize_5b	(SPI_CR1_DFF&0x04)
#define SPI_DataSize_6b	(SPI_CR1_DFF&0x05)
#define SPI_DataSize_7b	(SPI_CR1_DFF&0x06)
#define SPI_DataSize_8b	(SPI_CR1_DFF&0x07)
#define SPI_DataSize_9b	(SPI_CR1_DFF&0x08)
#define SPI_DataSize_10b	(SPI_CR1_DFF&0x09)
#define SPI_DataSize_11b	(SPI_CR1_DFF&0x0A)
#define SPI_DataSize_12b	(SPI_CR1_DFF&0x0B)
#define SPI_DataSize_13b	(SPI_CR1_DFF&0x0C)
#define SPI_DataSize_14b	(SPI_CR1_DFF&0x0D)
#define SPI_DataSize_15b	(SPI_CR1_DFF&0x0E)
#define SPI_DataSize_16b	(SPI_CR1_DFF&0x0F)
#define IS_SPI_DFF_SEL(SEL)	(((SEL) == SPI_DataSize_4b) || \
							((SEL) == SPI_DataSize_5b) || \
							((SEL) == SPI_DataSize_6b) || \
							((SEL) == SPI_DataSize_7b) || \
							((SEL) == SPI_DataSize_8b) || \
							((SEL) == SPI_DataSize_9b) || \
							((SEL) == SPI_DataSize_10b) || \
							((SEL) == SPI_DataSize_11b) || \
							((SEL) == SPI_DataSize_12b) || \
							((SEL) == SPI_DataSize_13b) || \
							((SEL) == SPI_DataSize_14b) || \
							((SEL) == SPI_DataSize_15b) || \
							((SEL) == SPI_DataSize_16b))

/** @defgroup SPI_CPOL **/
#define  SPI_CPOL_Low	((u16)0x0000)
#define  SPI_CPOL_High	SPI_CR1_CPOL
#define IS_SPI_CPOL_SEL(SEL)	(((SEL) == SPI_CPOL_Low) || \
								((SEL) == SPI_CPOL_High))
    
/** @defgroup SPI_CPHA **/
#define  SPI_CPHA_1Edge	((u16)0x0000)
#define  SPI_CPHA_2Edge	SPI_CR1_CPHA
#define IS_SPI_CPHA_SEL(SEL)	(((SEL) == SPI_CPHA_1Edge) || \
								((SEL) == SPI_CPHA_2Edge))
                           
/** @defgroup SPI_CSS  **/
#define  SPI_CSS_Soft	SPI_CSS_CSS
#define  SPI_CSS_Hard	((u16)0x0000)
#define IS_SPI_CSS_SEL(SEL)		(((SEL) == SPI_CSS_Soft) || \
								((SEL) == SPI_CSS_Hard))
                         
/** @defgroup IS_SPI_SCR_VAL  **/
#define IS_SPI_SCR_VAL(Value) ((Value) < 256)

/** @defgroup IS_SPI_BR_VAL  **/
#define IS_SPI_BR_VAL(Value) (((Value) > 1) && ((Value) < 255))


/** @defgroup IS_SPI_SWCS_SEL  **/
#define  SPI_CSSInternalSoft_Set			SPI_CSS_SWCS
#define  SPI_CSSInternalSoft_Reset			((u16)0x0000)
#define IS_SPI_SWCS_SEL(SEL)	(((SEL) == SPI_CSSInternalSoft_Reset) || \
								((SEL) == SPI_CSSInternalSoft_Set))
                                       
/** @defgroup IS_SPI_IE_SEL&GET  **/
#define IS_SPI_IE_SEL(SEL) ((((SEL) & (u8)0xF0) == 0) && ((SEL) != (u8)0x00))
#define IS_SPI_IE_GET(SEL)	(((SEL) == SPI_IE_OVRE) || \
							((SEL) == SPI_IE_OTE) || \
							((SEL) == SPI_IE_RXHE) || \
							((SEL) == SPI_IE_TXHE))
							
/** @defgroup IS_SPI_IFC_SEL  **/
#define IS_SPI_IFC_SEL(SEL) ((((SEL) & (u8)0xFC) == 0) && ((SEL) != (u8)0x00))

typedef enum
{
	SPI_FLAG_TXE = 0,
	SPI_FLAG_TNF, 
	SPI_FLAG_RXNE,
	SPI_FLAG_RXF,
	SPI_FLAG_BSY, 
	SPI_FLAG_OVR,
	SPI_FLAG_OT, 
	SPI_FLAG_RXH,
	SPI_FLAG_TXH    
} SPI_Flag_Enum;

/** @defgroup IS_SPI_SR1_SEL  **/
#define IS_SPI_SR_SEL(SEL)	(((SEL) == SPI_FLAG_TXE) || \
							((SEL) == SPI_FLAG_TNF) || \
							((SEL) == SPI_FLAG_RXNE) || \
							((SEL) == SPI_FLAG_RXF) || \
							((SEL) == SPI_FLAG_BSY) || \
							((SEL) == SPI_FLAG_OVR) || \
							((SEL) == SPI_FLAG_OT) || \
							((SEL) == SPI_FLAG_RXH) || \
							((SEL) == SPI_FLAG_TXH))
																	 
#define	SPI_CS_HIGH()	SPI_CSInternalSoftwareConfig(SPI, SPI_CSSInternalSoft_Set)
#define	SPI_CS_LOW()	SPI_CSInternalSoftwareConfig(SPI, SPI_CSSInternalSoft_Reset)
												
/* Exported macro ------------------------------------------------------------*/											
/* Exported functions ------------------------------------------------------- */
void SPI_Init(SPI_TypeDef* SPIx, SPI_InitTypeDef* SPI_InitStruct);
void SPI_StructInit(SPI_InitTypeDef* SPI_InitStruct);
void SPI_Cmd(SPI_TypeDef* SPIx, FunctionalState NewState);
void SPI_CSInternalSoftwareConfig(SPI_TypeDef* SPIx, u16 SPI_SWCS_SEL);
void SPI_SendData(SPI_TypeDef* SPIx, u16 Data);
u8 SPI_ReceiveData(SPI_TypeDef* SPIx);
void SPI_ITConfig(SPI_TypeDef* SPIx, u8 SPI_IT, FunctionalState NewState);
FlagStatus SPI_GetFlagStatus(SPI_TypeDef* SPIx, u16 SPI_FLAG);
void SPI_ClearFlag(SPI_TypeDef* SPIx, u16 SPI_FLAG);


/**
  * @}
  */

  
#ifdef __cplusplus
}
#endif

#endif 


