  /******************************************************************************
  * @file    PT32x033x_uart.h
  * @author  ӦÿŶ
  * @version V1.4.0
  * @date    2023/10/27
  * @brief    This file contains all the functions prototypes for the UART firmware library.
  *          
  ******************************************************************************
  * @attention
  *
  *
  *****************************************************************************/
    

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef PT32x033x_UART_H
#define PT32x033x_UART_H

#ifdef __cplusplus
extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x033x.h"


/** @addtogroup UART
  * @{
  */

/* Exported types ------------------------------------------------------------*/

/** @brief UART Init Structure definition **/
typedef struct
{
	uint32_t UART_BaudRate;
	u16 UART_WordLength;
	u16 UART_StopBits;
	u16 UART_Parity;
	u16 UART_Mode;
	u16 UART_LoopBack;
} UART_InitTypeDef;


/** @defgroup UART_FIFO_TYPE **/
typedef enum
{
	Rx_FIFO,
	Tx_FIFO
} UART_FifoTypeDef;


/* Exported constants --------------------------------------------------------*/

/** @defgroup UART_Oversampling_Rate **/
#define IS_UART_ALL_PERIPH(PERIPH)   ((PERIPH) == UART0)
#define IS_USART_0_PERIPH(PERIPH)      ((PERIPH) == UART0)

#define IS_UART_BR_VAL(Value)	(((Value) > 46) && ((Value) <= 3000000))

#define UART_WordLength_8D UART_WP_8D
#define UART_WordLength_8DP UART_WP_8DP
#define UART_WordLength_7DP UART_WP_7DP
#define UART_WordLength_9D UART_WP_9D

#define IS_UART_Fifo_SEL(SEL)      (((SEL) == Rx_FIFO)||((SEL)==Tx_FIFO))
														
#define IS_UART_WP_SEL(SEL)	(((SEL) == UART_WordLength_8D) || \
								((SEL) == UART_WordLength_8DP) || \
								((SEL) == UART_WordLength_7DP) || \
								((SEL) == UART_WordLength_9D))


#define UART_StopBits_1 UART_STOP_1b
#define UART_StopBits_0_5 UART_STOP_05b
#define UART_StopBits_1_5 UART_STOP_15b
#define UART_StopBits_2 UART_STOP_2b

#define IS_UART_STOP_SEL(SEL)	(((SEL) == UART_StopBits_0_5) || \
								((SEL) == UART_StopBits_1) || \
								((SEL) == UART_StopBits_1_5) || \
								((SEL) == UART_StopBits_2))

#define UART_Parity_Odd		UART_CR_PS
#define UART_Parity_Even		((u32)0x00000000)
#define IS_UART_PS_SEL(SEL)		(((SEL) == UART_Parity_Odd) || \
								((SEL) == UART_Parity_Even))
							
								
#define  UART_Mode_RxEnable	    UART_CR_RE			/* ݽʹ */
#define  UART_Mode_RxDisable	((u32)0x00000000)	/* ݽճ */
#define IS_UART_RE_SEL(SEL)		(((SEL) == UART_Mode_RxEnable) || \
								((SEL) == UART_Mode_RxDisable))

#define UART_LoopBack_Disable		((u16)0x0000)
#define UART_LoopBack_Enable		UART_CR_LPB
#define IS_UART_LoopBack_SEL(SEL)	(((SEL) == UART_LoopBack_Disable) || \
									((SEL) == UART_LoopBack_Enable))

/** @defgroup UART_Global_definition **/
#define IS_UART_DATA(DATA)             ((DATA) <= 0x1FF)
#define IS_UART_DUTYCYCLE(DUTYCYCLE)   ((DUTYCYCLE) <= 0x000004e2)//100/0.08=1250=0x4e2



/** @defgroup IS_UART_OWD_SEL **/
#define UART_OneLine_Tx		UART_CR_OWD
#define UART_OneLine_Rx		(~UART_CR_OWD)
#define IS_UART_OWD_SEL(SEL)	(((SEL) == UART_OneLine_Tx) || \
								((SEL) == UART_OneLine_Rx))

/** @defgroup IS_UART_TIMEOUT **/
#define IS_UART_TIMEOUT(SEL) (SEL!=0x00 && ((SEL&0xFFFFFF00) == 0x0))


/** @defgroup IS_UART_SR_SEL **/
#define UART_FLAG_RXNE UART_SR_RXNE
#define UART_FLAG_RXHF UART_SR_RXHF
#define UART_FLAG_RXF	UART_SR_RXF
#define UART_FLAG_RXCOT	UART_SR_RXCOT
#define UART_FLAG_IDLE	UART_SR_IDLE
#define UART_FLAG_PE	UART_SR_PE
#define UART_FLAG_FE	UART_SR_FE
#define UART_FLAG_OVR	UART_SR_OVR
#define UART_FLAG_TXE	UART_SR_TXE
#define UART_FLAG_TXHE	UART_SR_TXHE
#define UART_FLAG_TXF	UART_SR_TXF
#define UART_FLAG_TXO	UART_SR_TXO
#define IS_UART_FLAG(SEL)		(((SEL) == UART_FLAG_RXNE)   || \
								((SEL) == UART_FLAG_RXF)    || \
								((SEL) == UART_FLAG_RXCOT) 	|| \
								((SEL) == UART_FLAG_IDLE) 	|| \
								((SEL) == UART_FLAG_PE)    	|| \
								((SEL) == UART_FLAG_FE)   	|| \
								((SEL) == UART_FLAG_OVR) 		|| \
								((SEL) == UART_FLAG_TXE)    || \
								((SEL) == UART_FLAG_TXHE)    || \
								((SEL) == UART_FLAG_TXF)    || \
								((SEL) == UART_FLAG_TXO)		|| \
								((SEL) == UART_FLAG_RXHF))

/** @defgroup IS_UART_IE_SEL&GET **/
#define IS_UART_IE_SEL(SEL)		((((SEL) & (u16)0xF000) == 0) && ((SEL) != (u16)0x00))
#define IS_UART_IE_GET(SEL)		(((SEL) == UART_IE_RXNEI)  || \
								((SEL) == UART_IE_RXHFI)   || \
								((SEL) == UART_IE_RXFI)   || \
								((SEL) == UART_IE_RXCOTI)   || \
								((SEL) == UART_IE_IDLEI)   || \
								((SEL) == UART_IE_PEI) || \
								((SEL) == UART_IE_FEI)  || \
								((SEL) == UART_IE_OVRI) || \
								((SEL) == UART_IE_TXEI)   || \
								((SEL) == UART_IE_TXFI)   || \
								((SEL) == UART_IE_TXOI))
								
/** @defgroup IS_UART_IE_SEL&GET **/
#define IS_UART_IT_SEL(SEL)		((((SEL) & (u16)0xF000) == 0) && ((SEL) != (u16)0x00))
#define IS_UART_IT_GET(SEL)		(((SEL) == UART_FLAG_RXNE)   || \
								((SEL) == UART_FLAG_RXF)    || \
								((SEL) == UART_FLAG_PE)    || \
								((SEL) == UART_FLAG_FE)   || \
								((SEL) == UART_FLAG_OVR) || \
								((SEL) == UART_FLAG_TXE)    || \
								((SEL) == UART_FLAG_TXF)    || \
								((SEL) == UART_FLAG_TXO))



/* Exported macro ------------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */
void UART_Init(UART_TypeDef* UARTx, UART_InitTypeDef* UART_InitStruct);
void UART_StructInit(UART_InitTypeDef* UART_InitStruct);
void UART_Cmd(UART_TypeDef* UARTx, FunctionalState NewState);
void UART_SendData(UART_TypeDef* UARTx, u16 Data);
void UART_StringSend(UART_TypeDef* UARTx, uint8_t *String);
u16 UART_ReceiveData(UART_TypeDef* UARTx);
void UART_FifoReset(UART_TypeDef * UARTx,  UART_FifoTypeDef FIFO);
void UART_IrDACmd(UART_TypeDef* UARTx, FunctionalState NewState);
void UART_IrDAInvPinCmd(UART_TypeDef* UARTx, FunctionalState NewState);
void UART_SetDutyCycle(UART_TypeDef* UARTx, uint8_t UART_DutyCycle);
void UART_HalfDuplexCmd(UART_TypeDef* UARTx, FunctionalState NewState);
void UART_HalfDuplexDirConfig(UART_TypeDef* UARTx, u32 UART_OWD_SEL);
void UART_ITConfig(UART_TypeDef* UARTx, uint32_t UART_IT, FunctionalState NewState);
FlagStatus UART_GetFlagStatus(UART_TypeDef* UARTx, uint32_t UART_FLAG);
void UART_ClearFlag(UART_TypeDef* UARTx, uint32_t UART_CLEAR_FLAG);
ITStatus UART_GetITStatus(UART_TypeDef* UARTx, uint32_t UART_IT);

/**
  * @}
  */

  
#ifdef __cplusplus
}
#endif

#endif 


