  /******************************************************************************
  * @file    PT32x033x_wdg.h
  * @author  ӦÿŶ
  * @version V1.4.0
  * @date    2023/10/27
  * @brief    This file contains all the functions prototypes for the WDG firmware library.
  *          
  ******************************************************************************
  * @attention
  *
  *
  *****************************************************************************/
    

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef PT32x033x_WDG_H
#define PT32x033x_WDG_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x033x.h"

#define KR_KEY_DISABLE   ((u32)0xFFFFFFFF)
#define KR_KEY_ENABLE    ((u32)0x1ACCE551)

#define IWDG_LOCK_UnLock  KR_KEY_ENABLE
#define SWDG_LOCK_UnLock  KR_KEY_ENABLE

#define IWDG_LOCK_Status	WDG_LOCK_FLAG
#define IWDG_LOCK_Lock  ((u32)0x00000000)
#define SWDG_LOCK_Lock  ((u32)0x00000000)

/** @addtogroup WDG
  * @{
  */
  
/* Exported types ------------------------------------------------------------*/
/* Exported constants --------------------------------------------------------*/
#define IS_WDG_ALL_PERIPH(PERIPH)     (((PERIPH) == IWDG)||((PERIPH) == SWDG))

/** @defgroup IS_WDG_LOCK_SEL **/
#define IS_WDG_LOCK_SEL(SEL)	(((SEL) == IWDG_LOCK_UnLock) || \
								((SEL) == IWDG_LOCK_Lock))

/** @defgroup IS_WDG_SR_SEL **/
#define IWDG_FLAG_HungryDog      WDG_SR_HDF
#define IS_WDG_SR_SEL(SEL)		(((SEL) == IWDG_FLAG_HungryDog))

/** @defgroup IS_WDG_RLR_VAL **/
#define IS_WDG_RLR_VAL(Value) ((Value) <= 0xFFFFFFFF)


/* Exported macro ------------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */
void WDG_LockConfig(IWDG_TypeDef* WDGx, u32 WDG_WriteAccess);
FlagStatus WDG_GetLockStatus(IWDG_TypeDef* WDGx);
void WDG_SetReload(IWDG_TypeDef* WDGx, u32 Reload);
void WDG_ReloadCounter(IWDG_TypeDef* WDGx);
void WDG_Cmd(IWDG_TypeDef* WDGx, FunctionalState NewState);
FlagStatus WDG_GetFlagStatus(IWDG_TypeDef* WDGx, u16 WDG_FLAG);
ITStatus WDG_GetITStatus(IWDG_TypeDef* WDGx, u32 WDG_IT);
void WDG_ResetConfig(IWDG_TypeDef* WDGx, FunctionalState NewState);
void WDG_DbgPendingConfig(IWDG_TypeDef* WDGx, FunctionalState NewState);

/**
  * @}
  */

  
#ifdef __cplusplus
}
#endif

#endif 






