/******************************************************************************
  * @file    PT32x033x_Beep.c
  * @author  ӦÿŶ
  * @version V1.4.0
  * @date    2023/10/27
  * @brief   This file provides firmware functions to manage the following
  *          functionalities of the Beep peripheral:
  *           + Initialization and Configuration
  *           + Enable or Disble
  *          
  ******************************************************************************
  * @attention
  *
  *
  *****************************************************************************/

/* Includes ------------------------------------------------------------------*/
#include "PT32x033x_beep.h"

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/


#define BEEP_CR_DeInit_MASK ((u32)0x00000000)
#define BEEP_HCR_DeInit_MASK ((u32)0x00000000)
#define BEEP_CR_MASK ((u32)0xFFFFFF01)

/**
  * @brief
  * @param
  * @param
  * @retval
  */
/** @defgroup BEEP_Private_Functions
  * @{
  */
void Beep_Init(Beep_InitTypeDef* Beep_InitStruct)
{
	u32 tmpreg = 0;
	/* Check the parameters */
	assert_param(IS_BEEP_SUBDIV(Beep_InitStruct->BEEP_Subdivide));
	assert_param(IS_BEEP_CPSR(Beep_InitStruct->BEEP_Prescaler));
	/*  */
	tmpreg = BEEP->CR;
	/*  */
	tmpreg &= BEEP_CR_MASK;
	/*  */
	tmpreg  |= ((u32)(Beep_InitStruct->BEEP_Subdivide));
	tmpreg  |= ((u32)((Beep_InitStruct->BEEP_Prescaler) << 0x01));
	BEEP->CR = tmpreg;
}

/**
  * @brief  Enables or disables the  BEEP peripheral.
  * @param  NewState: new state of the USARTx peripheral.
  *          This parameter can be: ENABLE or DISABLE.
  * @retval None
  */
void Beep_Cmd(FunctionalState NewState)
{
	/* Check the parameters */
	assert_param(IS_FUNCTIONAL_STATE(NewState));
	if (NewState != DISABLE)
	{
		/**/
		BEEP->CR |= BEEP_CR_EN;
	}
	else
	{
		/* */
		BEEP->CR &= (u32)~((u32)BEEP_CR_EN);
	}
}
/**
  * @brief  DeInit BEEP.
  * @param  None.
  * @retval None.
  */
void Beep_DeInit(void)
{
	BEEP->CR=BEEP_CR_DeInit_MASK;
	BEEP->HCR=BEEP_HCR_DeInit_MASK;
}

/**
  * @brief  Enables or disables the  BEEP High Sink .
  * @param  NewState: new state of the BEEP peripheral.
  *          This parameter can be: ENABLE or DISABLE.
*		      PIN: BEEP_HighSink_PC2 or BEEP_HighSink_PD5
  * @retval None
  */
void Beep_HighSink(u32 pin,FunctionalState NewState)
{
	assert_param(IS_BEEP_PIN(pin));
	assert_param(IS_FUNCTIONAL_STATE(NewState));
	
	if (NewState != DISABLE)
	{
		/**/
		BEEP->HCR |= (u32)0x1<<pin;
	}
	else
	{
		/* */
		BEEP->HCR &= ~((u32)0x1<<pin);
	}
}
